# -*- coding: utf-8 -*-
"""First line is always wrong.

---
layout:     post
source:     Nobody
source_url: ???
title:      Firse line is always wrong.
date:       2014-06-10 12:31:19
categories: writing
---

The first line always is always wrong.

"""
from proselint.tools import reverse


def check(text):
    """Check the text."""
    error_code = "example.first"
    msg = "First line always has an error."

    reverse(text)

    return [(1, 1, error_code, msg)]



# -*- coding: utf-8 -*-
"""Mondegreens.

---
layout:     post
source:     Garner's Modern American Usage
source_url: http://bit.ly/1T4alrY
title:      mondegreens
date:       2014-06-10 12:31:19
categories: writing
---

Points out preferred form.

"""
from proselint.tools import memoize, preferred_forms_check


@memoize
def check(text):
    """Suggest the preferred forms."""
    err = "misc.mondegreens"
    msg = "'{}' is the preferred form."

    list = [
        ["a girl with kaleidoscope eyes", ["a girl with colitis goes by"]],
        ["a partridge in a pear tree",    ["a part-red gingerbread tree"]],
        ["attorney and notary public",    ["attorney and not a republic"]],
        ["beck and call",                 ["beckon call"]],
        ["for all intents and purposes",  ["for all intensive purposes"]],
        ["laid him on the green",         ["Lady Mondegreen"]],
        ["all of the other reindeer",     ["Olive, the other reindeer"]],
        ["to the manner born",            ["to the manor born"]],
    ]

    return preferred_forms_check(text, list, err, msg)



# -*- coding: utf-8 -*-
"""Pretension.

---
layout:     post
source:     ???
source_url: ???
title:      yelling
date:       2014-06-10 12:31:19
categories: writing
---

Never use the phrase 'all hell broke loose'.

"""
from proselint.tools import existence_check, memoize


@memoize
def check(text):
    """Check the text."""
    err = "ogilvy.pretension"
    msg = u"Jargon words like this one are the hallmarks of a pretentious ass."

    list = [
        "reconceptualize",
        "demassification",
        "attitudinally",
        "judgmentally",
    ]

    return existence_check(text, list, err, msg, max_errors=1)



# -*- coding: utf-8 -*-

"""in- vs. un-."""

from proselint.tools import memoize, preferred_forms_check


@memoize
def check(text):
    """in- vs un-."""
    err = "spelling.in_un"
    msg = "in- vs. un-. '{}' is the preferred spelling."

    preferences = [

        ["inadvisable",         ["unadvisable"]],
        ["inalienable",         ["unalienable"]],
        ["inexpressive",        ["unexpressive"]],
        ["infeasible",          ["unfeasible"]],
    ]

    return preferred_forms_check(text, preferences, err, msg)



# -*- coding: utf-8 -*-
"""Inferior / Superior.

---
layout:     post
source:     Fowler's Modern English Usage
source_url: bit.ly/1YBG8QJ
title:      Inferior / Superior
date:       2016-03-10 17:27:37
categories: writing
---

Corrects 'inferior/superior than' to 'inferior/superior to'.

"""
from proselint.tools import memoize, preferred_forms_check


@memoize
def check(text):
    """Suggest the preferred forms."""
    err = "misc.inferior_superior"
    msg = "'Inferior' and 'superior' are not true comparatives. Use '{}'."

    preferences = [
        ["inferior to",         ["inferior than"]],
        ["superior to",         ["superior than"]],
    ]

    return preferred_forms_check(text, preferences, err, msg)



"""Elementary Rules of Usage.

---
layout:     post
source:     Strunk & White
source_url: ???
title:      Elementary Rules of Usage
date:       2014-06-10 12:31:19
categories: writing
---

Strunk & White say:
1. Form the possessive singular of nouns by adding 's.
2. In a series of three or more terms with a conjunction, use a comma after
each term except the last.
3. Enclose parenthetic expressions between commas. ("This rule is difficult to
apply.")
4. Place a comma before a conjunction introducing an independent clause.
5. Do not join independent clauses with a comma; use a semi-colon. Or a period.
6. Do not break sentences in two. Do not use periods for the role of commas.
7. Use a colon after an independent clause if you introduce: a list of
particulars, an appositive, an application, or an illustrative quotation.
8. Use a dash to set off an abrupt break or interruption and to announce a
long appositive or summary.
9. The number of the subject determines the number of the verb. (MDPNB: This
will require nltk & syntactic parsing)
10. Use the proper case(grammatical gender) of pronouns.
    * MDPNB: hard case: "Give this work to whoever looks idle." `whoever looks
    idle` is the object of `to`.
11. A participial phrase at the beginning of a sentence must refer to the
grammatical subject.
"""

# from proselint.tools import memoize
# import re


# @memoize
# def check(text):
#     err = "strunk_white.usage"
#     msg = "Use of '{}'. {}"

#     bad_words = [
#         "obviously",
#         "utilize"
#     ]

#     explanations = {
#         "obviously":
#         "This is obviously an inadvisable word to use.",
#         "utilize":
#         r"Do you know anyone who *needs* to utilize the word utilize?"
#     }

#     errors = []
#     for word in bad_words:
#         occ = [m for m in re.finditer(word, text.lower())]
#         for o in occ:
#             errors.append((o.start(), o.end(), err,
#                           msg.format(word, explanations[word])))

#     return errors



# -*- coding: utf-8 -*-
"""Preferred forms.

---
layout:     post
source:     Garner's Modern American Usage
source_url: http://bit.ly/1T4alrY
title:      preferred forms
date:       2014-06-10 12:31:19
categories: writing
---

Points out preferred forms.

"""
from proselint.tools import memoize, preferred_forms_check


@memoize
def check(text):
    """Suggest the preferred forms."""
    err = "garner.preferred_forms"
    msg = "'{}' is the preferred form."

    preferences = [

        # Obsolete words
        ["imprimatur",          ["imprimature"]],

        # Proper nouns
        ["Halloween",           ["haloween", "hallowe'en"]],
        ["Khrushchev",          ["Khruschev", "Kruschev"]],
        ["Ku Klux Klan",        ["Klu Klux Klan"]],
        ["Pontius Pilate",      ["Pontius Pilot"]],

        # Plurals
        ["hippopotamuses",      ["hippopotami"]],
        ["manifestos",          ["manifesti"]],
        # ["matrixes",            ["matrices"]],
        ["mongooses",           ["mongeese"]],
        ["narcissi",            ["narcissuses"]],
        ["retinas",             ["retinae"]],
        ["sopranos",            ["soprani"]],
        ["titmice",             ["titmouses"]],

        # Hyphenated words
        ["long-standing",       ["longstanding"]],
        ["sans serif",          ["sans-serif", "sanserif"]],
        ["tortfeasor",          ["tort feasor", "tort-feasor"]],
        ["transship",           ["tranship", "trans-ship"]],
        ["transshipped",        ["transhipped", "trans-shipped"]],
        ["transshipping",       ["transhipping", "trans-shipping"]],
        ["non sequitur",        ["non-sequitur"]],

        # Misc
        ["attitude",            ["mental attitude"]],
        ["Chief Justice of the United States",
            ["Chief Justice of the United States Supreme Court",
             "Chief Justice of the Supreme Court of the United States."]],
        ["chitterlings",        ["chitlings", "chitlins"]],
        ["combustion engine",   ["combustible engine"]],
        ["during / throughout", ["for the duration of"]],
        ["foreclose on",        ["foreclose againt"]],
        ["friend in common",    ["mutual friend"]],
        ["in regard to",        ["in regards to"]],
        ["infectious",          ["infectuous"]],
        ["inferable",           ["inferrable", "inferrible"]],
        ["knowing that",        ["in light of the fact that"]],
        ["lanyard",             ["laniard"]],
        ["largess",             ["largesse"]],
        ["lasagna",             ["lasagne"]],
        ["leery",               ["leary"]],
        ["lend me her",         ["loan me her"]],
        ["lend me his",         ["loan me his"]],
        ["lend me their",       ["loan me their"]],
        ["lend me your",        ["loan me your"]],
        ["lent me her",         ["loaned me her"]],
        ["lent me his",         ["loaned me his"]],
        ["lent me their",       ["loaned me their"]],
        ["lent me your",        ["loaned me your"]],
        ["linguist",            ["linguistician"]],
        ["matzo-ball",          ["matzoh-ball",
                                 "matza-ball",
                                 "matzah-ball",
                                 "matsah-ball"]],
        ["mayoralty",           ["mayorality"]],
        ["mealy-mouthed",       ["mealymouthed"]],
        ["mean-spirited",       ["meanspirited"]],
        ["midwifed",            ["midwived"]],
        ["moniker",             ["monicker"]],
        ["musical revue",       ["musical review"]],
        ["mustache",            ["moustache"]],
        ["nonplussed",          ["nonplused"]],
        ["nonplussing",         ["nonplusing"]],
        ["non sequitur",        ["nonsequitur"]],
        ["not nearly as",       ["nowhere near as"]],
        ["off",                 ["off of"]],
        ["podiatrist",          ["chiropodist"]],
        ["podiatry",            ["chiropody"]],
        ["shoo-in",             ["shoe-in"]],
        ["suicide",             ["suicide victim"]],
        ["the highway median",  ["the highway medium"]],
        ["vaipidity",           ["vapidness"]],
        ["weather vane",        ["weather vein", "weather vain"]],
        ["with regard to",      ["with regards to"]],

        # Idioms
        ["a couple of people",  ["a couple people"]],
        ["all the time",        ["all of the time"]],
        ["as follows",          ["as follow"]],
        ["bulk large",          ["bulk largely"]],
        ["burying the lede",    ["burying the lead"]],
        ["came to naught",      ["came to nought"]],
        ["come off it",         ["come off of it"]],
        ["corroborating evidence", ["corroborative evidence"]],
        ["dear departed",       ["dearly departed"]],
        ["default on a loan",   ["default to a loan"]],
        ["draw an inference",   ["make an inference"]],
        ["in the meantime",     ["in the meanwhile"]],
        ["long distances",      ["lengthy distances"]],
        ["madding crowd",       ["maddening crowd"]],
        ["Magna Carta",         ["Magna Charta"]],
        ["marriage of convenience", ["mariage de convenance"]],
        ["Meanwhile,",          ["Meantime,"]],
        ["Midwest",             ["Middle West"]],
        ["Midwestern",          ["Middle Western"]],
        ["modi operandi",       ["modes of operandi"]],
        ["modus operandi",      ["mode of operandi"]],
        ["motion seconded",     ["notion seconded"]],
        ["mucous membranes",    ["mucus membranes"]],
        ["must pass muster",    ["must past muster"]],
        ["neck-and-neck",       ["neck-in-neck"]],
        ["no-holds-barred",     ["no-holes-barred"]],
        ["oil magnate",         ["oil magnet"]],
        ["punch up the lede",   ["punch up the lead"]],
        ["railroad magnate",    ["railroad magnet"]],
        ["seconded the motion", ["seconded the notion"]],
        ["statute of limitationas", ["statute of limits"]],
        ["take precedence over", ["take prescience over"]],
        ["the last two",        ["both of the last two"]],
        ["the last two",        ["both of the last"]],
        ["unorganic food",      ["inorganic food"]],
        ["vale of tears",       ["veil of tears"]],
        ["Venus flytrap",       ["Venus's flytrap", "Venus' flytrap"]],
        ["was accused of",      ["was accused with"]],

        # Verbosity
        ["try to",              ["make an attempt to"]],
        ["try to",              ["make attempts to"]],
        ["try to",              ["make efforts to"]],
        ["tried to",            ["made an attempt to"]],
        ["tried to",            ["made attempts to"]],
        ["tried to",            ["made efforts to"]],
        ["modern",              ["modern-day"]],

        # Grammar
        ["be misled",           ["be mislead"]],
        ["was misled",          ["was mislead"]],
        ["were misled",         ["were mislead"]],

        # Euphemisms
        ["a search-and-destroy mission", ["armed reconnaissance"]],
        ["abortion",            ["pregnancy termination"]],
        ["bisexual",            ["sexually ambidextrous"]],
        ["exterminator",        ["extermination engineer"]],
        ["firing",              ["permanent layoff"]],
        ["rat-catcher",         ["rodent operative"]],

        # Tenses
        ["mistook",             ["mistaked"]],

        # Accents
        ["né",                  ["ne"]],
        ["née",                 ["nee"]],
    ]

    return preferred_forms_check(text, preferences, err, msg)



# -*- coding: utf-8 -*-
"""Common errors with institution names.

---
layout:     post
source:     Institution's webpage
source_url: http://bit.ly/2en1zbv,
title:      Institution Name
date:       2016-11-16 11:46:19
categories: writing
---

Institution names.

"""
from proselint.tools import memoize, preferred_forms_check


@memoize
def check_vtech(text):
    """Suggest the correct name.

    source: Virginia Tech Division of Student Affairs
    source_url: http://bit.ly/2en1zbv
    """
    err = "institution.vtech"
    msg = "Incorrect name. Use '{}' instead of '{}'."

    institution = [
        ["Virginia Polytechnic Institute and State University",
         ["Virginia Polytechnic and State University"]],
    ]
    return preferred_forms_check(text, institution, err, msg)



# -*- coding: utf-8 -*-
"""Chatspeak.

---
layout:     post
source:     ???
source_url: ???
title:      textese
date:       2014-06-10 12:31:19
categories: writing
---

Chatspeak.

"""
from proselint.tools import existence_check, memoize


@memoize
def check(text):
    """Check the text."""
    err = "misc.chatspeak"
    msg = u"'{}' is chatspeak. Write it out."

    words = [
        "2day",
        "4U",
        "AFAIK",
        "AFK",
        "AFK",
        "ASAP",
        "B4",
        "brb",
        "btw",
        "cya",
        "GR8",
        "lol",
        "LOL",
        "LUV",
        "OMG",
        "rofl",
        "roftl",
        "sum1",
        "SWAK",
        "THNX",
        "THX",
        "TTYL",
        "XOXO"
    ]

    return existence_check(text, words, err, msg)



# -*- coding: utf-8 -*-

"""Em vs. im, en vs. in."""

from proselint.tools import memoize, preferred_forms_check


@memoize
def check(text):
    """em- vs. en-, im- vs. in-."""
    err = "spelling.em_im_en_in"
    msg = "em-, im-, en-, and in-. '{}' is the preferred spelling."

    preferences = [

        ["embalm",      ["imbalm"]],
        ["embark",      ["imbark"]],
        ["embed",       ["imbed"]],
        ["embitter",    ["imbitter"]],
        ["emblaze",     ["imblaze"]],
        ["embody",      ["imbody"]],
        ["embolden",    ["imbolden"]],
        ["embosom",     ["imbosom"]],
        ["embower",     ["imbower"]],
        ["embrown",     ["imbrown"]],
        ["empanel",     ["impanel"]],
        ["empower",     ["impower"]],
        ["encage",      ["incage"]],
        ["encapsulate", ["incapsulate"]],
        ["encase",      ["incase"]],
        ["enclasp",     ["inclasp"]],
        ["encumber",    ["incumber"]],
        ["encumbrance", ["incumbrance"]],
        ["endow",       ["indow"]],
        ["endowment",   ["indowment"]],
        ["endue",       ["indue"]],
        ["enfold",      ["infold"]],
        ["engraft",     ["ingraft"]],
        ["engulf",      ["ingulf"]],
        ["enlace",      ["inlace"]],
        ["enmesh",      ["inmesh"]],
        ["ensheathe",   ["insheathe"]],
        ["enshrine",    ["inshrine"]],
        ["ensnare",     ["insnare"]],
        ["ensoul",      ["insoul"]],
        ["ensphere",    ["insphere"]],
        ["enthrall",    ["inthrall"]],
        ["enthrone",    ["inthrone"]],
        ["entitle",     ["intitle"]],
        ["entomb",      ["intomb"]],
        ["entreat",     ["intreat"]],
        ["entrench",    ["intrench"]],
        ["entrust",     ["intrust"]],
        ["entwine",     ["intwine"]],
        ["entwist",     ["intwist"]],
        ["enwind",      ["inwind"]],
        ["enwrap",      ["inwrap"]],
        ["enwreathe",   ["inwreathe"]],
        ["imbrue",      ["embrue"]],
        ["impale",      ["empale"]],
        ["impoverish",  ["empoverish"]],
        ["inflame",     ["enflame"]],
        ["ingrain",     ["engrain"]],
        ["inure",       ["enure"]],
    ]

    return preferred_forms_check(text, preferences, err, msg)



# -*- coding: utf-8 -*-
"""Debased language.

---
layout:     post
source:     ???
source_url: ???
title:      yelling
date:       2014-06-10 12:31:19
categories: writing
---

Too much yelling.

"""
from proselint.tools import existence_check, memoize


@memoize
def check(text):
    """Check the text."""
    err = "misc.debased"
    msg = u"Bad usage, debased language, a continuous temptation."

    list = [
        "a not unjustifiable assumption",
        "leaves much to be desired",
        "would serve no purpose",
        "a consideration which we should do well to bear in mind",
    ]

    return existence_check(text, list, err, msg)



# -*- coding: utf-8 -*-
"""Hedging.

---
layout:     post
source:     Pinker's book on writing
source_url: ???
title:      hedging
date:       2014-06-10 12:31:19
categories: writing
---

Points out hedging.

"""
from proselint.tools import existence_check, memoize


@memoize
def check(text):
    """Suggest the preferred forms."""
    err = "hedging.misc"
    msg = "Hedging. Just say it."

    narcissism = [
        "I would argue that",
        ", so to speak",
        "to a certain degree",
    ]

    return existence_check(text, narcissism, err, msg)



# -*- coding: utf-8 -*-
"""Phrasal adjectives.

---
layout:     post
source:     Garner's Modern American Usage
source_url: http://bit.ly/1T4alrY
title:      Phrasal adjectives
date:       2014-06-10 12:31:19
categories: writing
---

Phrasal adjectives.

"""
from proselint.tools import existence_check, preferred_forms_check, memoize


@memoize
def check_ly(text):
    """Check the text."""
    err = "garner.phrasal_adjectives.ly"
    msg = u"""No hyphen is necessary in phrasal adjectives with an adverb
              ending in -ly, unless the -ly adverb is part of a longer
              phrase"""

    regex = r"\s[^\s-]+ly-"

    return existence_check(text, [regex], err, msg,
                           require_padding=False, offset=-1)


@memoize
def check(text):
    """Check the text."""
    err = "garner.phrasal_adjectives.examples"
    msg = u"""Hyphenate '{1}', a phrasal adjective, as '{0}'."""

    list = [
        ["across-the-board discounts", ["across the board discounts"]],
        ["acute-care treatment", ["acute care treatment"]],
        ["agreed-upon answer", ["agreed upon answer"]],
        ["big-ticket item", ["big ticket item"]],
        ["class-action lawyer", ["class action lawyer"]],
        ["criminal-law professor", ["criminal law professor"]],
        ["cut-and-dried issue", ["cut and dried issue"]],
        ["downward-sloping line", ["downward sloping line"]],
        ["English-language learners", ["English language learners"]],
        ["English-speaking people", ["English speaking people"]],
        ["even-numbered", ["even numbered"]],
        ["face-to-face meeting", ["fact to face meeting"]],
        ["fixed-rate mortgage", ["fixed rate mortgage"]],
        ["for-profit firm", ["for profit firm"]],
        ["foreign-sounding name", ["foreign sounding name"]],
        ["government-owned business", ["government owned business"]],
        ["hard-and-fast issue", ["hard and fast issue"]],
        ["head-on collision", ["head on collision"]],
        ["head-to-head battle", ["head to head battle"]],
        ["head-to-head competition", ["head to head competition"]],
        ["health-care coverage", ["heath care coverage"]],
        ["high-school student", ["high school student"]],
        ["hit-and-run statute", ["hit and run statute"]],
        ["HIV-negative person", ["HIV negative person"]],
        ["HIV-positive person", ["HIV positive person"]],
        ["information-technology personnel",
            ["information technology personnel"]],
        ["intellectual-property rights", ["intellectual property rights"]],
        ["interest-group pressures", ["interest group pressures"]],
        ["joint-stock company", ["joint stock company"]],
        ["kidney-dialysis machine", ["kidney dialysis machine"]],
        ["long-run costs", ["long run costs"]],
        ["long-term care", ["long term care"]],
        ["low-income housing", ["low income housing"]],
        ["mom-and-pop retail outlet", ["mom and pop retail outlet"]],
        ["mom-and-pop shop", ["mom and pop shop"]],
        ["national-security briefing", ["national security briefing"]],
        ["natural-gas pipeline", ["natural gas pipeline"]],
        ["no-fault accident", ["no fault accident"]],
        ["no-fault divorce", ["no fault divorce"]],
        ["no-fault insurance", ["no fault insurance"]],
        ["odd-numbered", ["odd numbered"]],
        ["office-supply store", ["office supply store"]],
        ["one-way flight", ["one way flight"]],
        ["one-way window", ["one way window"]],
        ["open-and-shut case", ["open and shut case"]],
        ["open-and-shut issue", ["open and shut issue"]],
        ["open-source community", ["open source community"]],
        ["optical-scan ballot", ["optical scan ballot"]],
        ["pension-fund investments", ["pension fund investments"]],
        ["private-sector employment", ["private sector employment"]],
        ["profit-seeking efforts", ["profit seeking efforts"]],
        ["punch-card ballot", ["punch card ballot"]],
        ["quality-adjusted price", ["quality adjusted price"]],
        ["razor-sharp intellect", ["razor sharp intellect"]],
        ["razor-sharp mind", ["razor sharp mind"]],
        ["razor-sharp mind", ["razor sharp mind"]],
        ["razor-sharp wit", ["razor sharp wit"]],
        ["larger-than-life personality", ["larger than life personality"]],
        ["real-estate prices", ["real estate prices"]],
        ["real-estate tycoon", ["real estate tycoon"]],
        ["right-wing militia", ["right wing militia"]],
        ["round-trip flight", ["round trip flight"]],
        ["search-and-rescue operation", ["search and rescue operation"]],
        ["second-largest army", ["second largest army"]],
        ["shell-shocked mothers", ["shell shocked mothers"]],
        ["shell-shocked soldiers", ["shell shocked soldiers"]],
        ["small-business loan", ["small business loan"]],
        ["small-business owner", ["small business owner"]],
        ["small-state senator", ["small state senator"]],
        ["small-animal veterinarian", ["small animal veterinarian"]],
        ["state-sponsored terrorism", ["state sponsored terrorism"]],
        ["state-sponsored violence", ["state sponsored violence"]],
        ["thumbs-up sign", ["thumbs up sign"]],
        ["time-honored tradition", ["time honored tradition"]],
        ["U.S.-led campaign", ["U.S. led campaign"]],
        ["upward-sloping line", ["upward sloping line"]],
        ["venture-backed company", ["venture backed company"]],
        ["well-publicized event", ["well publicized event"]],
        ["wire-transfer service", ["wire transfer service"]],
        ["yes-or-no question", ["yes or no question"]],
        ["zero-sum game", ["zero sum game"]],
        ["stained-glass ceiling", ["stained glass ceiling"]],
        ["stained-glass window", ["stained glass window"]],
        ["free-range chicken", ["free range chicken"]],
        ["free-range poultry", ["free range poultry"]],
        ["non-profit-making organization",
            ["non profit making organization",
             "non-profit making organization",
             "non profit-making organization"]],


        # Harmony
        ["three-part harmony", ["three part harmony"]],
        ["four-part harmony", ["four part harmony"]],
        ["six-part harmony", ["six part harmony"]],
        ["eight-part harmony", ["eight part harmony"]],

        # Losses and gains.
        ["first-quarter loss", ["first quarter loss"]],
        ["second-quarter loss", ["second quarter loss"]],
        ["third-quarter loss", ["third quarter loss"]],
        ["fourth-quarter loss", ["fourth quarter loss"]],
        ["first-quarter gain", ["first quarter gain"]],
        ["second-quarter gain", ["second quarter gain"]],
        ["third-quarter gain", ["third quarter gain"]],
        ["fourth-quarter gain", ["fourth quarter gain"]],

    ]

    return preferred_forms_check(text, list, err, msg)



# -*- coding: utf-8 -*-
"""Profession.

---
layout:     post
source:
source_url:
title:      Professions
date:       2014-06-10 12:31:19
categories: writing
---

Professions.

"""
from proselint.tools import memoize, preferred_forms_check


@memoize
def check(text):
    """Suggest the preferred forms."""
    err = "misc.professions"
    msg = "'{}' is the name of that job."

    preferences = [

        ["cobbler",    ["shoe repair guy"]],
        ["geometer",   ["geometrist"]],
    ]

    return preferred_forms_check(text, preferences, err, msg)



# -*- coding: utf-8 -*-
"""Corporate speak.

---
layout:     post
source:     Travis Bradberry for Inc.com
source_url: http://bit.ly/1IxWnto
title:      corporate speak
date:       2014-06-10 12:31:19
categories: writing
---

Avoid these cases of business jargon.

"""
from proselint.tools import existence_check, memoize


@memoize
def check(text):
    """Check the text."""
    err = "corporate_speak.misc"
    msg = u"Minimize your use of corporate catchphrases like this one."

    list = [
        "at the end of the day",
        "back to the drawing board",
        "hit the ground running",
        "get the ball rolling",
        "low-hanging fruit",
        "thrown under the bus",
        "think outside the box",
        "let's touch base",
        "get my manager's blessing",
        "it's on my radar",
        "ping me",
        "i don't have the bandwidth",
        "no brainer",
        "par for the course",
        "bang for your buck",
        "synergy",
        "move the goal post",
        "apples to apples",
        "win-win",
        "circle back around",
        "all hands on deck",
        "take this offline",
        "drill-down",
        "elephant in the room",
        "on my plate",
    ]

    return existence_check(text, list, err, msg, ignore_case=True)



# -*- coding: utf-8 -*-
"""Use the right symbols.

source:     Butterick's Practical Typography
source_url: http://practicaltypography.com/
"""

from proselint.tools import memoize, existence_check, preferred_forms_check


@memoize
def check_ellipsis(text):
    """Use an ellipsis instead of three dots."""
    err = "typography.symbols.ellipsis"
    msg = u"'...' is an approximation, use the ellipsis symbol '…'."
    regex = r"\.\.\."

    return existence_check(text, [regex], err, msg, max_errors=3,
                           require_padding=False, offset=0)


@memoize
def check_copyright_symbol(text):
    """Use the copyright symbol instead of (c)."""
    err = "typography.symbols.copyright"
    msg = u"(c) is a goofy alphabetic approximation, use the symbol ©."
    regex = r"\([cC]\)"

    return existence_check(
        text, [regex], err, msg, max_errors=1, require_padding=False)


@memoize
def check_trademark_symbol(text):
    """Use the trademark symbol instead of (TM)."""
    err = "typography.symbols.trademark"
    msg = u"(TM) is a goofy alphabetic approximation, use the symbol ™."
    regex = r"\(TM\)"

    return existence_check(
        text, [regex], err, msg, max_errors=3, require_padding=False)


@memoize
def check_registered_trademark_symbol(text):
    """Use the registered trademark symbol instead of (R)."""
    err = "typography.symbols.trademark"
    msg = u"(R) is a goofy alphabetic approximation, use the symbol ®."
    regex = r"\([rR]\)"

    return existence_check(
        text, [regex], err, msg, max_errors=3, require_padding=False)


@memoize
def check_sentence_spacing(text):
    """Use no more than two spaces after a period."""
    err = "typography.symbols.sentence_spacing"
    msg = u"More than two spaces after the period; use 1 or 2."
    regex = r"\. {3}"

    return existence_check(
        text, [regex], err, msg, max_errors=3, require_padding=False)


@memoize
def check_multiplication_symbol(text):
    u"""Use the multiplication symbol ×, not the lowercase letter x."""
    err = "typography.symbols.multiplication_symbol"
    msg = u"Use the multiplication symbol ×, not the letter x."
    regex = r"[0-9]+ ?x ?[0-9]+"

    return existence_check(
        text, [regex], err, msg, max_errors=3, require_padding=False)


@memoize
def check_curly_quotes(text):
    u"""Use curly quotes, not straight quotes."""
    err = "typography.symbols.curly_quotes"
    msg = u'Use curly quotes “”, not straight quotes "".'
    regex = r"\"[\w\s\d]+\""

    return existence_check(
        text, [regex], err, msg, max_errors=3, require_padding=False)

# @memoize
# def check_en_dash_separated_names(text):
#     """Use an en-dash to separate names."""
#     # [u"[A-Z][a-z]{1,10}[-\u2014][A-Z][a-z]{1,10}",
#     #     u"Use an en dash (–) to separate names."],



# -*- coding: utf-8 -*-
"""Animal adjectives.

---
layout:     post
source:     Garner's Modern American Usage
source_url: http://bit.ly/1T4alrY
title:      animal words
date:       2014-06-10 12:31:19
categories: writing
---

Animal words.

"""
from proselint.tools import memoize, preferred_forms_check


@memoize
def check(text):
    """Suggest the preferred forms."""
    err = "garner.animal_labels"
    msg = "There's a word for this: '{}'."

    preferences = [

        ["accipitrine",   ["hawk-like"]],
        ["anserine",      ["goose-like"]],
        ["aquiline",      ["eagle-like"]],
        ["avine",         ["bird-like"]],
        ["cancrine",      ["crab-like"]],
        ["hircine",       ["goat-like"]],
        ["damine",        ["deer-like"]],
        ["corvine",       ["crow-like", "raven-like"]],
        ["crocodiline",   ["crocodile-like"]],
        ["crotaline",     ["rattlesnake-like"]],
        ["falconine",     ["falcon-like"]],
        ["ferine",        ["wild animal-like"]],
        ["hippopotamine", ["hippopotamus-like"]],
        ["hirundine",     ["swallow-like"]],
        ["hystricine",    ["porcupine-like"]],
        ["lacertine",     ["lizard-like"]],
        ["laridine",      ["gull-like"]],
        ["leporine",      ["hare-like"]],
        ["lumbricine",    ["earthworm-like"]],
        ["lupine",        ["wolf-like"]],
        ["murine",        ["mouse-like"]],
        ["ovine",         ["sheep-like"]],
        ["pardine",       ["leopard-like", "panther-like"]],
        ["passerine",     ["sparrow-like"]],
        ["pavonine",      ["peacock-like"]],
        ["picine",        ["woodpecker-like"]],
        ["piscine",       ["fish-like"]],
        ["ranine",        ["frog-like"]],
        ["scolopendrine", ["centipede-like"]],
        ["soricine",      ["shrew-like"]],
        ["struthionine",  ["ostrich-like"]],
        ["suilline",      ["swine-like"]],
        ["taurine",       ["bull-like", "ox-like"]],
        ["tigrine",       ["tiger-like"]],
        ["vespine",       ["wasp-like"]],
        ["viperine",      ["viper-like"]],
        ["vituline",      ["calf-like", "veal-like"]],
        ["viverrine",     ["mongoose-like"]],
        ["vulpine",       ["fox-like"]],
        ["vulturine",     ["vulture-like"]],
        ["zebrine",       ["zebra-like"]],
        ["zibeline",      ["sable-like"]],
    ]

    return preferred_forms_check(text, preferences, err, msg)



# -*- coding: utf-8 -*-
"""Password in plain text.

---
layout:     post
source:     ???
source_url: ???
title:      Capitalization of abbreviations
date:       2014-06-10 12:31:19
categories: writing
---

In Hybrid Zones, p 255 in a citation Hughes & Huges Systems Experts and
Computers: The Systems Approach in Management and Engineering: World War Ii
and After.

World War Ii should have correct capitalization.
"""
from proselint.tools import blacklist, memoize


@memoize
def check(text):
    """Check the text."""
    err = "MSC104"
    msg = u"Don't fail to capitalize roman numeral abbreviations."

    pwd_regex = " (I(i*)|i*)"

    password = [
        "World War{}".format(pwd_regex),
    ]

    return blacklist(text, password, err, msg)



# -*- coding: utf-8 -*-
"""Annotation left in text.

---
layout:     post
source:     SublimeLinter-annotations
source_url: http://bit.ly/16Q7H41
title:      archaism
date:       2014-06-10 12:31:19
categories: writing
---

Annotation left in text.

"""
from proselint.tools import existence_check, memoize


@memoize
def check(text):
    """Check the text."""
    err = "annotations.misc"
    msg = u"Annotation left in text."

    annotations = [
        "FIXME",
        "FIX ME",
        "TODO",
        "todo",
        "ERASE THIS",
        "FIX THIS",
    ]

    return existence_check(
        text, annotations, err, msg, ignore_case=False, join=True)



# -*- coding: utf-8 -*-
"""Professional narcissism.

---
layout:     post
source:     Pinker's book on writing
source_url: ???
title:      professional narcissism
date:       2014-06-10 12:31:19
categories: writing
---

Points out academic narcissism.

"""
from proselint.tools import memoize, existence_check


@memoize
def check(text):
    """Suggest the preferred forms."""
    err = "pinker.narcissism"
    msg = "Professional narcissism. Talk about the subject, not its study."

    narcissism = [
        "In recent years, an increasing number of [a-zA-Z]{3,}sts have",
    ]

    return existence_check(text, narcissism, err, msg)



# -*- coding: utf-8 -*-
"""Too much yelling.

---
layout:     post
source:     ???
source_url: ???
title:      yelling
date:       2014-06-10 12:31:19
categories: writing
---

Too much yelling.

"""
import re

from proselint.tools import existence_check, memoize


@memoize
def check_repeated_exclamations(text):
    """Check the text."""
    err = "leonard.exclamation.multiple"
    msg = u"Stop yelling. Keep your exclamation points under control."

    regex = r"[\!]\s*?[\!]{1,}"

    return existence_check(
        text, [regex], err, msg, require_padding=False, ignore_case=False,
        max_errors=1, dotall=True)


@memoize
def check_exclamations_ppm(text):
    """Make sure that the exclamation ppm is under 30."""
    err = "leonard.exclamation.30ppm"
    msg = u"More than 30 ppm of exclamations. Keep them under control."

    regex = r"\w!"

    count = len(re.findall(regex, text))
    num_words = len(text.split(" "))

    ppm = (count*1.0 / num_words) * 1e6

    if ppm > 30 and count > 1:
        loc = re.search(regex, text).start() + 1
        return [(loc, loc+1, err, msg, ".")]
    else:
        return []



# -*- coding: utf-8 -*-
"""Credit card number printed.

---
layout:     post
source:     ???
source_url: ???
title:      credit card number printed
date:       2014-06-10 12:31:19
categories: writing
---

Credit card number printed.

"""
from proselint.tools import existence_check, memoize


@memoize
def check(text):
    """Check the text."""
    err = "security.credit_card"
    msg = u"Don't put credit card numbers in plain text."

    credit_card_numbers = [
        r"4\d{15}",
        r"5[1-5]\d{14}",
        r"3[4,7]\d{13}",
        r"3[0,6,8]\d{12}",
        r"6011\d{12}",
    ]

    return existence_check(text, credit_card_numbers, err, msg)



# -*- coding: utf-8 -*-
"""GLAAD.

---
layout:     post
source:     GLAAD Media Reference Guide - 9th Edition
source_url: http://www.glaad.org/reference
title:      GLAAD Guidelines
date:       2016-07-06
categories: writing
---

This check looks for offensive terms related to LGBTQ issues and
raises an error marking them as offensive. The New York Times and
Associated Press have also adopted this style guide.

"""
from proselint.tools import memoize, existence_check


@memoize
def check(text):
    """Flag offensive words based on the GLAAD reference guide."""
    err = "glaad.offensive_terms"
    msg = "Offensive term. Remove it or consider the context."

    list = [
        "fag",
        "faggot",
        "dyke",
        "sodomite",
        "homosexual agenda",
        "gay agenda",
        "transvestite",
        "homosexual lifestyle",
        "gay lifestyle"
        # homo - may create false positives without additional context
        # FIXME use topic detetor to decide whether "homo" is offensive
    ]

    return existence_check(text, list, err, msg, join=True, ignore_case=False)



# -*- coding: utf-8 -*-
"""GLAAD.

---
layout:     post
source:     GLAAD Media Reference Guide - 9th Edition
source_url: http://www.glaad.org/reference
title:      GLAAD Guidelines
date:       2016-07-06
categories: writing
---

This check looks for possibly offensive terms related to LGBTQ issues and
makes more acceptable recommendations. TheNew York Times and
Associated Press have also adopted this style guide.

"""
from proselint.tools import memoize, preferred_forms_check


@memoize
def check(text):
    """Suggest preferred forms given the reference document."""
    err = "glaad.terms"
    msg = "Possibly offensive term. Consider using '{}' instead of '{}'."

    list = [
        ["gay man",            ["homosexual man"]],
        ["gay men",            ["homosexual men"]],
        ["lesbian",            ["homosexual woman"]],
        ["lesbians",           ["homosexual women"]],
        ["gay people",         ["homosexual people"]],
        ["gay couple",         ["homosexual couple"]],
        ["sexual orientation", ["sexual preference"]],
        ["openly gay",         ["admitted homosexual", "avowed homosexual"]],
        ["equal rights",       ["special rights"]]
        ]

    return preferred_forms_check(text, list, err, msg, ignore_case=False)



# -*- coding: utf-8 -*-
"""Hyperbolic language.

---
layout:     post
source:     ???
source_url: ???
title:      hyperbolic language
date:       2014-06-10 12:31:19
categories: writing
---

Hyperbolic language.

"""
from proselint.tools import existence_check, memoize


@memoize
def check(text):
    """Check the text."""
    err = "hyperbolic.misc"
    msg = u"'{}' is hyperbolic."

    words = [
        r"[a-z]*[!]{2,}",
        r"[a-z]*\?{2,}"
    ]

    return existence_check(text, words, err, msg)



# -*- coding: utf-8 -*-
"""Airlinese.

---
layout:     post
source:     Garner's Modern American Usage
source_url: http://bit.ly/1T4alrY
title:      Airlinese
date:       2014-06-10 12:31:19
categories: writing
---

Airlinese.

"""
from proselint.tools import existence_check, memoize


@memoize
def check(text):
    """Check the text."""
    err = "airlinese.misc"
    msg = u"'{}' is airlinese."

    airlinese = [
        "enplan(?:e|ed|ing|ement)",
        "deplan(?:e|ed|ing|ement)",
        "taking off momentarily",
    ]

    return existence_check(text, airlinese, err, msg)



# -*- coding: utf-8 -*-
u"""Cliches.

---
layout:     post
source:     Garner's Modern American Usage
source_url: http://bit.ly/1T4alrY
title:      a vs. an
date:       2014-06-10 12:31:19
categories: writing
---

Cliches are cliché.

"""
from proselint.tools import memoize, existence_check


@memoize
def check(text):
    """Check the text."""
    err = "jargon.misc"
    msg = u"'{}' is jargon. Can you replace it with something more standard?"

    jargon = [
        "in the affirmative",
        "in the negative",
        "agendize",
        "per your order",
        "per your request",
        "disincentivize",
    ]

    return existence_check(text, jargon, err, msg, join=True)



# -*- coding: utf-8 -*-
"""Words the NFL won't print on a jersey.

---
layout:     post
source:     The National Football League
source_url: http://bit.ly/1ISK0rb
title:      words the NFL won't print on a jersey
date:       2014-06-10 12:31:19
categories: writing
---

Words the NFL won't print on a jersey.

"""
from proselint.tools import existence_check, memoize


@memoize
def check(text):
    """Check the text."""
    err = "cursing.nfl"
    msg = u"The NFL won't print this word on a jersey."

    list = [
        "420",
        "666",
        "2 on 1",
        "3rd eye",
        "3rd leg",
        "3rdeye",
        "3rdleg",
        "3some",
        "4 twenty",
        "4twenty",
        "60 nine",
        "60nine",
        "a.s.s.",
        "anal",
        "anal annie",
        "anal sex",
        "analannie",
        "analsex",
        "anus",
        "arse",
        "ass",
        "ass bagger",
        "ass blaster",
        "ass clown",
        "ass cowboy",
        "ass fuck",
        "ass fucker",
        "ass hole",
        "ass holes",
        "ass hore",
        "ass jockey",
        "ass kiss",
        "ass kisser",
        "ass klown",
        "ass lick",
        "ass licker",
        "ass lover",
        "ass man",
        "ass monkey",
        "ass munch",
        "ass muncher",
        "ass packer",
        "ass pirate",
        "ass puppies",
        "ass ranger",
        "ass whore",
        "ass wipe",
        "assbagger",
        "assblaster",
        "assclown",
        "asscowboy",
        "assfuck",
        "assfucker",
        "asshole",
        "assholes",
        "asshore",
        "assjockey",
        "asskiss",
        "asskisser",
        "assklown",
        "asslick",
        "asslicker",
        "asslover",
        "assman",
        "assmonkey",
        "assmunch",
        "assmuncher",
        "asspacker",
        "asspirate",
        "asspuppies",
        "assranger",
        "asswhore",
        "asswipe",
        "athletes foot",
        "athletesfoot",
        "axing the weasel",
        "b hard",
        "back door",
        "back door man",
        "backdoor",
        "backdoorman",
        "backseat",
        "bad ass",
        "bad fuck",
        "badfuck",
        "ball licker",
        "ball sack",
        "balllicker",
        "balls",
        "ballsack",
        "banging",
        "barely legal",
        "barelylegal",
        "barf",
        "barf face",
        "barface",
        "barfface",
        "bastard",
        "bazongas",
        "bazooms",
        "beastality",
        "beastiality",
        "beat off",
        "beat your meat",
        "beatoff",
        "beat-off",
        "beatyourmeat",
        "bi",
        "bi sexual",
        "biatch",
        "big ass",
        "big bitch",
        "big bitch",
        "big butt",
        "bigass",
        "bigbastard",
        "bigbutt",
        "bisexual",
        "bi-sexual",
        "bitch",
        "bitches",
        "bitchin",
        "bitchy",
        "bite me",
        "biteme",
        "black out",
        "blackout",
        "blow job",
        "blowjob",
        "bm",
        "boner",
        "bong",
        "boobies",
        "boobs",
        "boody",
        "breast",
        "breast job",
        "breast lover",
        "breast man",
        "breastjob",
        "breastlover",
        "breastman",
        "budweiser",
        "bull crap",
        "bull dike",
        "bull dyke",
        "bull shit",
        "bullcrap",
        "bulldike",
        "bulldyke",
        "bullshit",
        "bumble fuck",
        "bumblefuck",
        "bumfuck",
        "bunghole",
        "butch babes",
        "butch dike",
        "butch dyke",
        "butchbabes",
        "butchdike",
        "butchdyke",
        "butt bang",
        "butt fuck",
        "butt fucker",
        "butt fuckers",
        "butt head",
        "butt man",
        "butt plug",
        "butt stain",
        "buttbang",
        "butt-bang",
        "buttface",
        "buttfuck",
        "butt-fuck",
        "buttfucker",
        "butt-fucker",
        "buttfuckers",
        "butt-fuckers",
        "butthead",
        "buttman",
        "buttpirate",
        "buttplug",
        "buttstain",
        "camel toe",
        "cameltoe",
        "carpet muncher",
        "carpetmuncher",
        "carruth",
        "cherry popper",
        "cherrypopper",
        "chick slick",
        "chickslick",
        "clam digger",
        "clam diver",
        "clamdigger",
        "clamdiver",
        "clit",
        "clitoris",
        "cock",
        "cock block",
        "cock blocker",
        "cock cowboy",
        "cock fight",
        "cock knob",
        "cock licker",
        "cock lover",
        "cock nob",
        "cock queen",
        "cock rider",
        "cock smith",
        "cock sucker",
        "cock tail",
        "cock tease",
        "cockblock",
        "cockblocker",
        "cockcowboy",
        "cockfight",
        "cockhead",
        "cockknob",
        "cocklicker",
        "cocklover",
        "cocknob",
        "cockqueen",
        "cockrider",
        "cocks man",
        "cocksman",
        "cocksmith",
        "cocksucer",
        "cocksucker",
        "cocktail",
        "cocktease",
        "cocky",
        "condom",
        "copulate",
        "corn hole",
        "cornhole",
        "crabs",
        "crack",
        "crack pipe",
        "crack whore",
        "crackpipe",
        "crackwhore",
        "crack-whore",
        "crap",
        "crappy",
        "creamy",
        "crotch",
        "crotch jockey",
        "crotch monkey",
        "crotch rot",
        "crotchjockey",
        "crotchmonkey",
        "crotchrot",
        "cum",
        "cum bubble",
        "cum fest",
        "cum jockey",
        "cum quat",
        "cum queen",
        "cum shot",
        "cumbubble",
        "cumfest",
        "cumjockey",
        "cumm",
        "cumming",
        "cumquat",
        "cumqueen",
        "cumshot",
        "cunnilingus",
        "cunt",
        "cunt fuck",
        "cunt fucker",
        "cunt licker",
        "cuntfuck",
        "cuntfucker",
        "cuntlicker",
        "cyber sex",
        "cyber slimer",
        "cybersex",
        "cyberslimer",
        "dahmer",
        "damn",
        "damn it",
        "damnit",
        "datnigga",
        "dd",
        "deap throat",
        "deaper",
        "deapthroat",
        "deep throat",
        "deeper",
        "deepthroat",
        "defecate",
        "deposit",
        "devil",
        "dick brain",
        "dick fart",
        "dick for brains",
        "dick head",
        "dick lick",
        "dick licker",
        "dick likcer",
        "dick wad",
        "dick weed",
        "dickbrain",
        "dickforbrains",
        "dickhead",
        "dickless",
        "dicklick",
        "dicklicker",
        "dickman",
        "dickwad",
        "dickweed",
        "dike",
        "dildo",
        "dip stick",
        "dipstick",
        "dirty ho",
        "dix",
        "dixie dike",
        "dixie dyke",
        "dixiedike",
        "dixiedyke",
        "do me",
        "doggie style",
        "doggiestyle",
        "doggy stlye",
        "doggystyle",
        "dome",
        "dong",
        "dope",
        "double d",
        "doubled",
        "drag queen",
        "dragqueen",
        "dragqween",
        "dre",
        "drip dick",
        "dripdick",
        "drunk",
        "drunken",
        "dumb ass",
        "dumb bitch",
        "dumb fuck",
        "dumbass",
        "dumbbitch",
        "dumbfuck",
        "easy slut",
        "easyslut",
        "eat me",
        "eat pussy",
        "eatballs",
        "eatme",
        "eatpussy",
        "ejaculate",
        "erection",
        "evl",
        "excrement",
        "f toyota",
        "f.i.n.e.",
        "f.u.c.k.",
        "face fucker",
        "facefucker",
        "faggot",
        "fagot",
        "fairy",
        "fanny fucker",
        "fannyfucker",
        "fart",
        "fast fuck",
        "fastfuck",
        "fat ass",
        "fat fuck",
        "fat fucker",
        "fatass",
        "fatfuck",
        "fatfucker",
        "fatso",
        "fellatio",
        "femme",
        "finger food",
        "finger fuck",
        "finger fucker",
        "fingerfood",
        "fingerfuck",
        "fingerfucker",
        "fist fuck",
        "fist fucker",
        "fistfuck",
        "fistfucker",
        "fisting",
        "flasher",
        "flatulence",
        "floggin the dolphin",
        "fondle",
        "foot fuck",
        "foot fucker",
        "foot licker",
        "footaction",
        "footfuck",
        "footfucker",
        "footlicker",
        "footstar",
        "fore skin",
        "foreskin",
        "fornicate",
        "four 20",
        "four twenty",
        "four20",
        "fourtwenty",
        "freak fuck",
        "freakfuck",
        "freaky fucker",
        "freakyfucker",
        "free 4 all",
        "free for all",
        "free fuck",
        "free4all",
        "freeforall",
        "freefuck",
        "fuck",
        "fuck bag",
        "fuck buddy",
        "fuck face",
        "fuck fest",
        "fuck freak",
        "fuck friend",
        "fuck head",
        "fuck her",
        "fuck it",
        "fuck knob",
        "fuck me",
        "fuck me hard",
        "fuck monkey",
        "fuck off",
        "fuck pig",
        "fuck them",
        "fuck whore",
        "fuck you",
        "fucka",
        "fuckable",
        "fuckbag",
        "fuckbuddy",
        "fucked",
        "fucked up",
        "fuckedup",
        "fucker",
        "fuckers",
        "fuckface",
        "fuckfest",
        "fuckfreak",
        "fuckfriend",
        "fuckhead",
        "fuckher",
        "fuckin",
        "fuckin a",
        "fuckin nuts",
        "fuckin right",
        "fuckina",
        "fucking",
        "fucking a",
        "fucking bitch",
        "fucking nuts",
        "fuckingbitch",
        "fuckinnuts",
        "fuckinright",
        "fuckit",
        "fuckknob",
        "fuckme",
        "fuckmehard",
        "fuckmonkey",
        "fuckoff",
        "fuckpig",
        "fuckwhore",
        "fuckyou",
        "fudge pakcers",
        "fun fuck",
        "funfuck",
        "fuuck",
        "g unit",
        "gang bang",
        "gang banger",
        "gangbang",
        "gangbanger",
        "gay",
        "gay ass",
        "gay mutha fuckin queer",
        "gay pride",
        "gaymuthafuckinwhore",
        "genital",
        "get it on",
        "getiton",
        "giehn",
        "give head",
        "givehead",
        "glazed donut",
        "glazeddonut",
        "go me",
        "go to hell",
        "god",
        "god damed mutha fucka",
        "god damit",
        "god damn",
        "god damned",
        "god manit",
        "goddamit",
        "goddamn",
        "goddamned",
        "goddamnes",
        "goddamnit",
        "goddamnmuthafucker",
        "gonorrehea",
        "gonzagas",
        "gook",
        "got jesus",
        "got2haveit",
        "gotohell",
        "g-unit",
        "hand job",
        "handjob",
        "hard on",
        "harder",
        "hardon",
        "harem",
        "he hate me",
        "head fuck",
        "head lights",
        "headfuck",
        "headlights",
        "hehateme",
        "hell",
        "hell no",
        "hell yes",
        "hellno",
        "hellyes",
        "hen house",
        "henhouse",
        "herpes",
        "hershey hi way",
        "hersheyhighway",
        "hersheyhiway",
        "hershy high way",
        "ho",
        "ho mo",
        "hobo",
        "hole",
        "hole stuffer",
        "holestuffer",
        "homo",
        "homo bangers",
        "homo sexual",
        "homobangers",
        "homosexual",
        "honkers",
        "honkey",
        "hooker",
        "hookers",
        "hooters",
        "hore",
        "horney",
        "horny",
        "horseshit",
        "hose job",
        "hosejob",
        "hoser",
        "hostage",
        "hot damn",
        "hot pussy",
        "hot to trot",
        "hot2trot",
        "hotdamn",
        "hotpussy",
        "hottotrot",
        "hussy",
        "hustler",
        "i love beer",
        "i luv beer",
        "id ten t",
        "id10t",
        "idiot",
        "idoit",
        "in the ass",
        "in the buff",
        "ingin",
        "insest",
        "inter course",
        "inter racial",
        "intercourse",
        "interracial",
        "intheass",
        "inthebuff",
        "jack the ripper",
        "jackass",
        "jackoff",
        "jacktheripper",
        "jap",
        "jap crap",
        "japcrap",
        "jerk off",
        "jerkoff",
        "jesus chirst",
        "jesuschrist",
        "jism",
        "jiz",
        "jiz juice",
        "jizim",
        "jizjuice",
        "jizz",
        "jizzim",
        "joint",
        "juggalo",
        "jugs",
        "k mart",
        "kill",
        "killer",
        "killing",
        "kiss ass",
        "kissass",
        "kkk",
        "kmart",
        "knockers",
        "koon",
        "kotex",
        "krap",
        "krappy",
        "kum",
        "kum bubble",
        "kum quat",
        "kumbubble",
        "kumbullbe",
        "kumquat",
        "kunt",
        "ky",
        "ky jelly",
        "lactate",
        "lady boog",
        "laid",
        "lap dance",
        "lapdance",
        "lesbain",
        "lesbayn",
        "lesbian",
        "lesbin",
        "lesbo",
        "lez",
        "lez be",
        "lez be friends",
        "lezbe",
        "lezbefriends",
        "lezbo",
        "lezz",
        "lezzo",
        "lick me",
        "licker",
        "lickme",
        "limp dick",
        "limpdick",
        "limy",
        "live sex",
        "livesex",
        "loaded gun",
        "loadedgun",
        "lolita",
        "looser",
        "lotion",
        "love bone",
        "love goo",
        "love gun",
        "love juice",
        "love muscle",
        "love pistol",
        "love rocket",
        "lovebone",
        "lovegoo",
        "lovegun",
        "lovejuice",
        "lovemuscle",
        "lovepistol",
        "loverocket",
        "low life",
        "lowlife",
        "lube job",
        "lubejob",
        "lucky camel toe",
        "luckycammeltoe",
        "magic wand",
        "magicwand",
        "mams",
        "man hater",
        "man paste",
        "manhater",
        "manpaste",
        "mary jane",
        "maryjane",
        "mastabate",
        "mastabater",
        "master blaster",
        "masterbate",
        "masterblaster",
        "mastrabator",
        "mattress princess",
        "mattressprincess",
        "meat beatter",
        "meatbeatter",
        "molest",
        "molester",
        "molestor",
        "money shot",
        "moneyshot",
        "mother fucker",
        "mother love bone",
        "motherfuck",
        "motherfucker",
        "motherlovebone",
        "muff",
        "muff dive",
        "muff diver",
        "muff licker",
        "muffdive",
        "muffdiver",
        "muffin diver",
        "muffindiver",
        "mufflikcer",
        "murder",
        "mutha fucker",
        "naked",
        "nasty bitch",
        "nasty ho",
        "nasty slut",
        "nasty whore",
        "nastybitch",
        "nastyho",
        "nastyslut",
        "nastywhore",
        "neon deon",
        "nig",
        "niger",
        "nigga",
        "nigger",
        "nipple",
        "nipple ring",
        "nipplering",
        "nit tit",
        "nittit",
        "no fucking way",
        "no sex",
        "nofuckingway",
        "nookie",
        "nooner",
        "nude",
        "nut fucker",
        "nutfucker",
        "oicu812",
        "on the rag",
        "ontherag",
        "orgasm",
        "orgy",
        "ou812",
        "oui",
        "p i m p",
        "pearl necklace",
        "pearlnecklace",
        "pecker",
        "pee",
        "peep show",
        "peepshow",
        "peepshpw",
        "penetration",
        "penis",
        "penthouse",
        "period",
        "phque",
        "pimp",
        "pimp simp",
        "pimped",
        "pimper",
        "pimpjuic",
        "pimpjuice",
        "pimpsimp",
        "piss",
        "piss head",
        "pissed",
        "pisser",
        "pisshead",
        "play boy",
        "play girl",
        "playboy",
        "playgirl",
        "pocket pool",
        "pocketpool",
        "polack",
        "poon tang",
        "poontang",
        "poop",
        "pooper",
        "poor white trash",
        "poorwhitetrash",
        "popimp",
        "porch monkey",
        "porchmonkey",
        "porn",
        "porn flick",
        "porn king",
        "porn princess",
        "pornflick",
        "pornking",
        "porno",
        "pornprincess",
        "pot",
        "premature",
        "prick",
        "prick head",
        "prickhead",
        "primetime",
        "prostitute",
        "pubic",
        "pubic lice",
        "pubiclice",
        "pud",
        "pud boy",
        "pudboy",
        "pudd",
        "pudd boy",
        "puddboy",
        "pun tang",
        "puntang",
        "purina princess",
        "purinapricness",
        "pussy",
        "pussy cat",
        "pussy eater",
        "pussy fucker",
        "pussy licker",
        "pussy lips",
        "pussy lover",
        "pussy pounder",
        "pussycat",
        "pussyeater",
        "pussyfucker",
        "pussylicker",
        "pussylips",
        "pussylover",
        "pussypounder",
        "putt pirate",
        "pwt",
        "queef",
        "queer",
        "quickie",
        "rae carruth",
        "rape",
        "rapist",
        "rear end",
        "rear entry",
        "rearend",
        "rearentry",
        "rectum",
        "red light",
        "redlight",
        "reefer",
        "rent a fuck",
        "rentafuck",
        "retard",
        "retarded",
        "ribbed",
        "rim job",
        "rimjob",
        "roach",
        "robber",
        "s and m",
        "s&m",
        "samckdaddy",
        "sandm",
        "satan",
        "schlong",
        "screw",
        "screw you",
        "screwyou",
        "scrotum",
        "semen",
        "sex",
        "sex farm",
        "sex hound",
        "sex house",
        "sex kitten",
        "sex pot",
        "sex slave",
        "sex to go",
        "sex toy",
        "sex toys",
        "sex whore",
        "sexfarm",
        "sexhound",
        "sexhouse",
        "sexkitten",
        "sexpot",
        "sexslave",
        "sextogo",
        "sextoy",
        "sextoys",
        "sexual",
        "sexwhore",
        "sexy",
        "sexy biatch",
        "sexy bitch",
        "sexy moma",
        "sexy slim",
        "sexymoma",
        "sexy-slim",
        "shag",
        "shaggin",
        "shagging",
        "shawtypimp",
        "shit",
        "shit dick",
        "shit eater",
        "shit face",
        "shit for brains",
        "shit fuck",
        "shit fucker",
        "shit happens",
        "shit head",
        "shit out of luck",
        "shit stain",
        "shit4brains",
        "shitdick",
        "shiteater",
        "shitface",
        "shitforbrains",
        "shitfuck",
        "shitfucker",
        "shithapens",
        "shithappens",
        "shithead",
        "shitoutofluck",
        "shits",
        "shitstain",
        "shitter",
        "shitting",
        "shitty",
        "short fuck",
        "shortfuck",
        "showtime",
        "six six six",
        "sixsixsix",
        "sixty 9",
        "sixty nine",
        "sixty9",
        "sixtynine",
        "skank",
        "skank bitch",
        "skank fuck",
        "skank whore",
        "skankbitch",
        "skankfuck",
        "skankwhore",
        "skanky bitch",
        "skanky whore",
        "skankybitch",
        "skankywhore",
        "skin flute",
        "skinflute",
        "skum",
        "skum bag",
        "skumbag",
        "slant",
        "slant eye",
        "slanteye",
        "slave",
        "slave driver",
        "slavedriver",
        "sleeze bag",
        "sleeze ball",
        "sleezebag",
        "sleezeball",
        "slide it in",
        "slideitin",
        "slime",
        "slime ball",
        "slime bucket",
        "slimeball",
        "slimebucket",
        "slut",
        "slut wear",
        "slut whore",
        "sluts",
        "slutt",
        "slutting",
        "slutty",
        "slutwear",
        "slutwhore",
        "smack daddy",
        "smack the monkey",
        "smackthemonkey",
        "smagma",
        "smart ass",
        "snatch",
        "snatch patch",
        "snatchpatch",
        "sniper",
        "snot",
        "sob",
        "sodomite",
        "sodomy",
        "son of a bitch",
        "sonofabitch",
        "sonofbitch",
        "spank the monkey",
        "spankthemonkey",
        "sperm",
        "sperm bag",
        "sperm hearder",
        "sperm herder",
        "spermacide",
        "spermbag",
        "spermhearder",
        "spermherder",
        "spic",
        "spick",
        "spit",
        "spitter",
        "split tail",
        "split tial",
        "splittail",
        "stagg",
        "strap on",
        "strapon",
        "stringer",
        "strip club",
        "stripclub",
        "stroke",
        "stroking",
        "stupid",
        "stupid fuck",
        "stupid fucker",
        "stupidfuck",
        "stupidfucker",
        "suck",
        "suck dick",
        "suck me",
        "suck my ass",
        "suck my dick",
        "suck my tit",
        "suck off",
        "suckdick",
        "sucker",
        "suckme",
        "suckmyass",
        "suckmydick",
        "suckmytit",
        "suckoff",
        "suicide",
        "swallow",
        "swallower",
        "swalow",
        "sweetness",
        "swign dixx",
        "swing dixx",
        "swingin dixx",
        "swinging dicks",
        "syphilis",
        "tampon",
        "tang",
        "testicle",
        "testicles",
        "third eye",
        "third leg",
        "thirdeye",
        "thirdleg",
        "three some",
        "threesome",
        "tit",
        "tit bit nipply",
        "tit fuck",
        "tit fucker",
        "tit fuckin",
        "tit job",
        "tit licker",
        "tit lover",
        "titbitnipply",
        "titfuck",
        "titfucker",
        "titfuckin",
        "titjob",
        "titlicker",
        "titlover",
        "tits",
        "titties",
        "titty",
        "toilet",
        "toilet bowl",
        "tongethruster",
        "tongue",
        "tongue thruster",
        "tongue tramp",
        "tonguethrust",
        "tonguetramp",
        "toung thruster",
        "tounge baller",
        "tounge thrust",
        "trailer trash",
        "trailertrash",
        "tramp",
        "tri sexual",
        "triple x",
        "triplex",
        "trisexual",
        "trojan",
        "trots",
        "tunnel of love",
        "tunneloflove",
        "turd",
        "two bit whore",
        "two on one",
        "twobitwhore",
        "unfuckable",
        "up the ass",
        "up the butt",
        "upskirt",
        "uptheass",
        "upthebutt",
        "urinate",
        "urine",
        "uterus",
        "vagina",
        "vaginal",
        "vd",
        "vibrater",
        "vibrator",
        "virgin",
        "virgin breaker",
        "virginbreaker",
        "vulva",
        "waysted",
        "weenie",
        "wet spot",
        "wetspot",
        "whacker",
        "whiskey dick",
        "whiskeydick",
        "whisky dick",
        "whiskydick",
        "white trash",
        "whitetrash",
        "whore",
        "whore fucker",
        "whore house",
        "whorefucker",
        "whorehouse",
        "wigger",
        "willie wanker",
        "williewanker",
        "wuutang",
        "xxx",
        "yellow man",
        "yellowman"
    ]

    return existence_check(text, list, err, msg)



# -*- coding: utf-8 -*-
u"""Suddenly.

---
layout:     post
source:     Reference for Writers
source_url: http://bit.ly/1E94vyD
title:      suddenly
date:       2014-06-10 12:31:19
categories: writing
---

“Sudden” means quickly and without warning, but using the word “suddenly” both
slows down the action and warns your reader. Do you know what’s more effective
for creating the sense of the sudden? Just saying what happens.

When using “suddenly,” you communicate through the narrator that the action
seemed sudden. By jumping directly into the action, you allow the reader to
experience that suddenness first hand. “Suddenly” also suffers from being
nondescript, failing to communicate the nature of the action itself; providing
no sensory experience or concrete fact to hold on to. Just … suddenly.

Feel free to employ “suddenly” in situations where the suddenness is not
apparent in the action itself. For example, in “Suddenly, I don’t hate you
anymore,” the “suddenly” substantially changes the way we think about the
shift in emotional calibration.
"""
from proselint.tools import memoize, existence_check


@memoize
def check(text):
    """Advice on sudden vs suddenly."""
    err = "misc.suddenly"
    msg = u"Suddenly is nondescript, slows the action, and warns your reader."
    regex = "Suddenly,"

    return existence_check(text, [regex], err, msg, max_errors=3,
                           require_padding=False, offset=-1, ignore_case=False)



# -*- coding: utf-8 -*-
"""Too much yelling.

---
layout:     post
source:     ???
source_url: ???
title:      yelling
date:       2014-06-10 12:31:19
categories: writing
---

Never use the phrase 'all hell broke loose'.

"""
from proselint.tools import existence_check, memoize


@memoize
def check_repeated_exclamations(text):
    """Check the text."""
    err = "leonard.hell"
    msg = u"Never use the words 'all hell broke loose'."

    regex = r"all hell broke loose"

    return existence_check(
        text, [regex], err, msg, max_errors=1)



# -*- coding: utf-8 -*-
"""From whence it came.

---
layout:     post
source:     unknown
source_url: unknown
title:      whence
date:       2014-06-10 12:31:19
categories: writing
---

From whence it came.

"""
from proselint.tools import existence_check, memoize


@memoize
def check(text):
    """Check the text."""
    err = "misc.whence"
    msg = u"The 'from' in 'from whence' is not needed."

    return existence_check(text, ["from whence"], err, msg)



"""Elementary Rules of Usage.

---
layout:     post
source:     Strunk & White
source_url: ???
title:      Elementary Principles of Composition
date:       2014-06-10 12:31:19
categories: writing
---

Strunk & White say:
1. Choose a suitable design and hold to it.
    * MDPNB: Sounds like a principle of `consistency`.
2. Make the paragraph the unit of composition.
    * MDPNB: This can be generalized to say something about variability in the
    length of paragraphs and sentences. When any device is too often used it
    becomes a mannerism.
    * MDPNB: Sounds like a principle of `variation`.
3. Use the active voice.
4. Put statements in positive form.
    * MDPNB: In some cases this will apply as an invective against the use of
    a double negative.
    * Ex: He was not very often on time. -> He usually came late.
    * Ex:
4.1. Placing negative and positive in opposition makes for a stronger
structure.
    * Ex. Not charity, but simple justice.
    * Not that I loved Caesar less, but that I loved Rome more.
4.2. Do not use unnecessary auxiliaries or conditionals.
5. Use definite, specific, concrete language.
    * A period of unfavorable weather set in. ->It rained every day for a week.
6. Omit needless words.
    * `The fact that` is particularly pernicious.
    * `who is, which was` and the like are often superfluous
7. Avoid a succession of loose sentences.
    * MDPNB Principle of brevity. Take 2.
8. Express coordinate ideas in similar form.
    * MDPNB: Principle of parallel structure.
    * MDPNB: This one will be hard...
9. Keep related words together.
    * MDPNB: Principle of localism in semantics.
10. In summaries, keep to one tense.
    * MDPNB: Principle of temporal consistency.
11. Place the emphatic word of a sentence at the end.
    * MDPNB: Principle of recency.
"""
from proselint.tools import memoize, preferred_forms_check


@memoize
def check(text):
    """Suggest the preferred forms."""
    err = "strunk_white.composition"
    msg = "Try '{}' instead of '{}'."

    bad_forms = [
        # Put statements in positive form
        ["dishonest",               ["not honest"]],
        ["trifling",                ["not important"]],
        ["forgot",                  ["did not remember"]],
        ["ignored",                 ["did not pay (any )?attention to"]],
        ["distrusted",              ["did not have much confidence in"]],

        # Omit needless words
        ["whether",                 ["the question as to whether"]],
        ["no doubt",                ["there is no doubt but that"]],
        ["used for fuel",           ["used for fuel purposes"]],
        ["he",                      ["he is a man who"]],
        ["hastily",                 ["in a hasty manner"]],
        ["this subject",            ["this is a subject that"]],
        ["Her story is strange.",   ["Her story is a strange one."]],
        ["because",                 ["the reason why is that"]],
        ["because / since",         ["owing to the fact that"]],
        ["although / though",       ["in spite of the fact that"]],
        ["remind you / notify you",
            ["call your attention to the fact that"]],
        ["I did not know that / I was unaware that",
            ["I was unaware of the fact that"]],
        ["his failure",             ["the fact that he had not succeeded"]],
        ["my arrival",              ["the fact that i had arrived"]]
    ]

    return preferred_forms_check(text, bad_forms, err, msg)



# -*- coding: utf-8 -*-
"""Incorrect capitalization.

---
layout:     post
source:     Garner's Modern American Usage
source_url: http://bit.ly/1T4alrY
title:      incorrect captalization
date:       2014-06-10 12:31:19
categories: writing
---

Incorrect capitalization.

"""
from proselint.tools import memoize, preferred_forms_check


@memoize
def check(text):
    """Suggest the preferred forms."""
    err = "misc.captalization"
    msg = "Incorrect capitalization. '{}' is the preferred form."

    list = [
        ["Stone Age",          ["stone age"]],
        ["space age",          ["Space Age"]],
        ["the American West",  ["the American west"]],
        ["Mother Nature",      ["mother nature"]],
    ]

    return preferred_forms_check(text, list, err, msg, ignore_case=False)


# @memoize
# def check_seasons(text):
#     """Suggest the preferred forms."""
#     err = "MAU102"
#     msg = "Seasons shouldn't be capitalized. '{}' is the preferred form."

#     list = [
#         # ["winter",        ["Winter"]],
#         # ["fall",          ["Fall"]],
#         # ["summer",        ["Summer"]],
#         # ["spring",        ["Spring"]],
#     ]

#     return preferred_forms_check(text, list, err, msg, ignore_case=False)


@memoize
def check_months(text):
    """Suggest the preferred forms."""
    err = "MAU102"
    msg = "Months should be capitalized. '{}' is the preferred form."

    list = [

        ["January",         ["january"]],
        ["February",        ["february"]],
        # ["March",           ["march"]],
        ["April",           ["april"]],
        # ["May",             ["may"]],
        ["June",            ["june"]],
        ["July",            ["july"]],
        ["August",          ["august"]],
        ["September",       ["september"]],
        ["October",         ["october"]],
        ["November",        ["november"]],
        ["December",        ["december"]],
    ]

    return preferred_forms_check(text, list, err, msg, ignore_case=False)


@memoize
def check_days(text):
    """Suggest the preferred forms."""
    err = "MAU102"
    msg = "Days of the week should be capitalized. '{}' is the preferred form."

    list = [

        ["Monday",       ["monday"]],
        ["Tuesday",      ["tuesday"]],
        ["Wednesday",    ["wednesday"]],
        ["Thursday",     ["thursday"]],
        ["Friday",       ["friday"]],
        ["Saturday",     ["saturday"]],
        ["Sunday",       ["sunday"]],
    ]

    return preferred_forms_check(text, list, err, msg, ignore_case=False)



# -*- coding: utf-8 -*-

"""Redundancy."""

from proselint.tools import memoize, preferred_forms_check


@memoize
def check(text):
    """Suggest the preferred forms."""
    err = "redundancy.wallace"
    msg = "Redundancy. Use '{}' instead of '{}'."

    redundancies = [
        ["rectangular",        ["rectangular in shape"]],
        ["audible",            ["audible to the ear"]],
    ]
    return preferred_forms_check(text, redundancies, err, msg)


@memoize
def check_garner(text):
    """Suggest the preferred forms.

    source:     Garner's Modern American Usage
    source_url: http://bit.ly/1T4alrY
    """
    err = "redundancy.garner"
    msg = "Redundancy. Use '{}' instead of '{}'."

    redundancies = [
        ["adequate",          ["adequate enough"]],
        ["admitted",          ["self-admitted"]],
        ["affidavit",         ["sworn affidavit"]],
        ["agreement",         ["mutual agreement"]],
        ["alumnus",           ["former alumnus"]],
        ["antithetical",      ["directly antithetical"]],
        ["approximately",     ["approximately about"]],
        ["associate",         ["associate together(?: in groups)?"]],
        ["bivouac",           ["temporary bivouac", "bivouac camp"]],
        ["blend",             ["blend together"]],
        ["but",               ["but nevertheless"]],
        ["charged with...",   ["accused of a charge"]],
        ["circumstances of",  ["circumstances surrounding"]],
        ["circumstances",     ["surrounding circumstances"]],
        ["close",             ["close proximity"]],
        ["collaborate",       ["collaborate together"]],
        ["collaborator",      ["fellow collaborator"]],
        ["collaborators",     ["fellow collaborators"]],
        ["collocated",        ["collocated together"]],
        ["colleagues",        ["fellow colleagues"]],
        ["combine",           ["combine together"]],
        ["complacent",        ["self-complacent"]],
        ["confessed",         ["self-confessed"]],
        ["connect",           ["connect together"]],
        ["consensus",         ["(?:general )?consensus of opinion"]],
        ["consolidate",       ["consolidate together"]],
        ["continues to",      ["still continues to"]],
        ["contradictory",     ["mutually contradictory"]],
        ["cooperation",       ["mutual cooperation"]],
        ["couple",            ["couple together"]],
        ["crisis",            ["serious crisis"]],
        ["eliminate",         ["entirely eliminate"]],
        ["especially",        ["most especially"]],
        ["fact",              ["actual fact"]],
        ["facts",             ["true facts"]],
        ["forecast",          ["future forecast"]],
        ["founding fathers",  ["founding forefathers"]],
        ["free",              ["free and gratis"]],
        ["free",              ["free gratis"]],
        ["full",              ["completely full"]],
        ["fundamentals",      ["basic fundamentals"]],
        ["gift",              ["free gift"]],
        ["innovation",        ["new innovation"]],
        ["interact",          ["interact with each other"]],
        ["large",             ["large-size"]],
        ["meld",              ["meld together"]],
        ["merge",             ["merge together"]],
        ["mingle",            ["mingle together"]],
        ["mix",               ["mix together"]],
        ["mutual feelings",   ["mutual feelings for eachother"]],
        ["mutual respect",    ["mutual respect for each other"]],
        ["native citizen",    ["native-born citizen"]],
        ["necessity",         ["absolute necessity"]],
        ["obvious",           ["blatantly obvious"]],
        ["pause",             ["pause for a moment"]],
        ["planning",          ["advance planning"]],
        ["plans",             ["future plans"]],
        ["pooled",            ["pooled together"]],
        ["potable water",     ["potable drinking water"]],
        ["potable water",     ["potable drinking water"]],
        ["recruit",           ["new recruit"]],
        ["reelected",         ["reelected for another term"]],
        ["refer",             ["refer back"]],
        ["regress",           ["regress back"]],
        ["repay them",        ["repay them back"]],
        ["repay",             ["repay back"]],
        ["repeat",            ["repeat again"]],
        ["repeat",            ["repeat back"]],
        ["repeat",            ["repeat the same"]],
        ["repeated",          ["repeated the same"]],
        ["reprieve",          ["temporary reprieve"]],
        ["respite",           ["brief respite"]],
        ["retirement",        ["retiral", "retiracy"]],
        ["retreat",           ["retreat back"]],
        ["return",            ["return back"]],
        ["scrutinize",        ["closely scrutinize"]],
        ["software",          ["software program"]],
        ["surrounded",        ["surrounded on all sides"]],
        ["the nation",        ["the whole entire nation"]],
        ["throughout the",    ["throughout the entire"]],
        ["timpani",           ["timpani drum"]],
        ["twins",             ["pair of twins"]],
        ["vacancy",           ["unfilled vacancy"]],
        ["various",           ["various different"]],
        ["veteran",           ["former veteran"]],
        ["visible",           ["visible to the eye"]],
        ["vocation",          ["professional vocation"]],
        ["while",             ["while at the same time"]],
    ]

    return preferred_forms_check(text, redundancies, err, msg)


@memoize
def check_nordquist(text):
    """Suggest the preferred forms.

    source:     Richard Nordquist
    source_url: http://grammar.about.com/bio/Richard-Nordquist-22176.htm
    """
    err = "redundancy.nordquist"
    msg = "Redundancy. Use '{}' instead of '{}'."

    redundancies = [
        ["essential",          ["absolutely essential"]],
        ["necessary",          ["absolutely necessary"]],
        ["a.m.",               ["a.m. in the morning"]],
        ["p.m.",               ["p.m. at night"]],
    ]
    return preferred_forms_check(text, redundancies, err, msg)


@memoize
def check_atd(text):
    """Check for redundancies from After the Deadline."""
    err = "after_the_deadline.redundancy"
    msg = "Redundancy. Use '{}' instead of '{}'."

    redundancies = [
        [u"Bō",               ["Bo Staff"]],
        ["Challah",           ["Challah bread"]],
        ["Hallah",            ["Hallah bread"]],
        ["Challah",           ["Challah bread"]],
        ["I",                 ["I myself", "I personally"]],
        ["Mount Fuji",        ["Mount Fujiyama"]],
        ["Milky Way",         ["Milky Way galaxy"]],
        ["Rio Grande",        ["Rio Grande river"]],
        ["adage",             ["old adage"]],
        ["add",               ["add a further", "add an additional"]],
        ["advance",           ["advance forward"]],
        ["alternative",       ["alternative choice"]],
        ["amaretto",          ["amaretto almond"]],
        ["annihilate",        ["completely annihilate"]],
        ["anniversary",       ["annual anniversary"]],
        ["anonymous",         ["unnamed anonymous"]],
        ["as",                ["equally as"]],
        ["ascend",            ["ascend up"]],
        ["ask",               ["ask the question"]],
        ["assemble",          ["assemble together"]],
        ["at present the",    ["at the present time the"]],
        ["at this point",     ["at this point in time"]],
        ["attach",            ["attach together"]],
        ["autumn",            ["autumn season"]],
        ["bald",              ["bald-headed"]],
        ["balsa",             ["balsa wood"]],
        ["belongings",        ["personal belongings"]],
        ["benefits",          ["desirable benefits"]],
        ["bento",             ["bento box"]],
        ["best",              ["best ever"]],
        ["bit",               ["tiny bit"]],
        ["blend",             ["blend together"]],
        ["bond",              ["common bond"]],
        ["bonus",             ["added bonus", "extra bonus"]],
        ["bouquet",           ["bouquet of flowers"]],
        ["breakthrough",      ["major breakthrough"]],
        ["bride",             ["new bride"]],
        ["brief",             ["brief in duration"]],
        ["bruin",             ["bruin bear"]],
        ["hot",               ["burning hot"]],
        ["cacophony",         ["cacophony of sound"]],
        ["cameo",             ["brief cameo", "cameo appearance"]],
        ["cancel",            ["cancel out"]],
        ["cash",              ["cash money"]],
        ["chai",              ["chai tea"]],
        ["chance",            ["random chance"]],
        ["charm",             ["personal charm"]],
        ["circle",            ["circle around", "round circle"]],
        ["circulate",         ["circulate around"]],
        ["classify",          ["classify into groups"]],
        ["classmates",        ["fellow classmates"]],
        ["cliche",            ["old cliche", "overused cliche"]],
        ["climb",             ["climb up"]],
        ["clock",             ["time clock"]],
        ["collaborate",       ["collaborate together"]],
        ["collaboration",     ["joint collaboration"]],
        ["colleague",         ["fellow colleague"]],
        ["combine",           ["combine together"]],
        ["commute",           ["commute back and forth"]],
        ["compete",           ["compete with each other"]],
        ["comprise",          ["comprise of"]],
        ["comprises",         ["comprises of"]],
        ["conceived",         ["first conceived"]],
        ["conclusion",        ["final conclusion"]],
        ["confer",            ["confer together"]],
        ["confrontation",     ["direct confrontation"]],
        # ["confused",          ["confused state"]],
        ["connect",           ["connect together", "connect up"]],
        ["consensus",         ["consensus of opinion", "general consensus"]],
        ["consult",           ["consult with"]],
        ["conversation",      ["oral conversation"]],
        ["cool",              ["cool down"]],
        ["cooperate",         ["cooperate together"]],
        ["cooperation",       ["mutual cooperation"]],
        ["copy",              ["duplicate copy"]],
        ["core",              ["inner core"]],
        ["cost",              ["cost the sum of"]],
        ["could",             ["could possibly"]],
        ["coupon",            ["money-saving coupon"]],
        ["created",           ["originally created"]],
        ["crisis",            ["crisis situation"]],
        ["crouch",            ["crouch down"]],
        ["currently",         ["now currently"]],
        ["custom",            ["old custom", "usual custom"]],
        ["danger",            ["serious danger"]],
        ["dates",             ["dates back"]],
        ["decision",          ["definite decision"]],
        ["depreciate",        ["depreciate in value"]],
        ["descend",           ["descend down"]],
        ["destroy",           ["totally destroy"]],
        ["destroyed",         ["completely destroyed"]],
        ["destruction",       ["total destruction"]],
        ["details",           ["specific details"]],
        ["dilemma",           ["difficult dilemma"]],
        ["disappear",         ["disappear from sight"]],
        ["discovered",        ["originally discovered"]],
        ["dive",              ["dive down"]],
        ["done",              ["over and done with"]],
        ["drawing",           ["illustrated drawing"]],
        ["drop",              ["drop down"]],
        ["dune",              ["sand dune"]],
        ["during",            ["during the course of"]],
        ["dwindle",           ["dwindle down"]],
        ["dwindled",          ["dwindled down"]],
        ["every",             ["each and every"]],
        ["earlier",           ["earlier in time"]],
        ["eliminate",         ["completely eliminate", "eliminate altogether",
                               "entirely eliminate"]],
        ["ember",             ["glowing ember"]],
        ["embers",            ["burning embers"]],
        ["emergency",         ["emergency situation", "unexpected emergency"]],
        ["empty",             ["empty out"]],
        ["enclosed",          ["enclosed herein"]],
        ["end",               ["final end"]],
        ["engulfed",          ["completely engulfed"]],
        ["enter",             ["enter in", "enter into"]],
        ["equal",             ["equal to one another"]],
        ["eradicate",         ["eradicate completely"]],
        ["essential",         ["absolutely essential"]],
        ["estimated at",      ["estimated at about",
                               "estimated at approximately",
                               "estimated at around"]],
        ["etc.",              ["and etc."]],
        ["evolve",            ["evolve over time"]],
        ["exaggerate",        ["over exaggerate"]],
        ["exited",            ["exited from"]],
        ["experience",        ["actual experience", "past experience"]],
        ["experts",           ["knowledgeable experts"]],
        ["extradite",         ["extradite back"]],
        ["face the consequences", ["face up to the consequences"]],
        ["face the fact",     ["face up to the fact"]],
        ["face the challenge", ["face up to the challenge"]],
        ["face the problem",  ["face up to the problem"]],
        ["facilitate",        ["facilitate easier"]],
        ["fact",              ["established fact"]],
        ["facts",             ["actual facts", "hard facts", "true facts"]],
        ["fad",               ["passing fad"]],
        ["fall",              ["fall down"]],
        ["fall",              ["fall season"]],
        ["feat",              ["major feat"]],
        ["feel",              ["feel inside"]],
        ["feelings",          ["inner feelings"]],
        ["few",               ["few in number"]],
        ["filled",            ["completely filled", "filled to capacity"]],
        ["first",             ["first of all"]],
        ["first time",        ["first time ever"]],
        ["fist",              ["closed fist"]],
        ["fly",               ["fly through the air"]],
        ["focus",             ["focus in", "main focus"]],
        ["follow",            ["follow after"]],
        ["for example",       ["as for example"]],
        # ["foremost",          ["first and foremost"]],
        ["forever",           ["forever and ever"]],
        ["free",              ["for free"]],
        ["friend",            ["personal friend"]],
        ["friendship",        ["personal friendship"]],
        ["full",              ["full to capacity"]],
        ["fundamentals",      ["basic fundamentals"]],
        ["fuse",              ["fuse together"]],
        ["gather",            ["gather together", "gather up"]],
        ["get up",            ["get up on his feet", "get up on your feet"]],
        ["gift",              ["free gift"]],
        ["gifts",             ["free gifts"]],
        ["goal",              ["ultimate goal"]],
        # ["graduate",          ["former graduate"]],
        ["grow",              ["grow in size"]],
        ["guarantee",         ["absolute guarantee"]],
        ["gunman",            ["armed gunman"]],
        ["gunmen",            ["armed gunmen"]],
        ["habitat",           ["native habitat"]],
        ["had done",          ["had done previously"]],
        ["halves",            ["two equal halves"]],
        # ["has",               ["has got"]],
        # ["have",              ["have got"]],
        ["haven",             ["safe haven"]],
        # ["he",                ["he himself"]],
        ["heat",              ["heat up"]],
        ["history",           ["past history"]],
        ["hoist",             ["hoist up"]],
        ["hole",              ["empty hole"]],
        ["honcho",            ["head honcho"]],
        ["ice",               ["frozen ice"]],
        ["ideal",             ["perfect ideal"]],
        ["identical",         ["same identical"]],
        ["identification",    ["positive identification"]],
        ["imports",           ["foreign imports"]],
        ["impulse",           ["sudden impulse"]],
        ["in fact",           ["in actual fact"]],
        ["in the yard",       ["outside in the yard"]],
        ["inclusive",         ["all inclusive"]],
        ["incredible",        ["incredible to believe"]],
        ["incumbent",         ["present incumbent"]],
        # ["indicted",          ["indicted on a charge"]],
        ["industry",          ["private industry"]],
        ["injuries",          ["harmful injuries"]],
        ["innovation",        ["new innovation"]],
        ["innovative",        ["innovative new", "new innovative"]],
        # ["input",             ["input into"]],
        ["instinct",          ["natural instinct", "naturally instinct"]],
        ["integrate",         ["integrate together",
                               "integrate with each other"]],
        ["interdependent",    ["interdependent on each other",
                               "mutually interdependent"]],
        ["introduced",        ["introduced for the first time"]],
        ["invention",         ["new invention"]],
        ["kneel",             ["kneel down"]],
        ["knots",             ["knots per hour"]],
        # ["last",              ["last of all"]],
        # ["later",             ["later time"]],
        ["lift",              ["lift up"]],
        ["lingers",           ["still lingers"]],
        ["look to the future", ["look ahead to the future"]],
        ["love triangle",     ["three-way love triangle"]],
        ["maintained",        ["constantly maintained"]],
        ["manually",          ["manually by hand"]],
        ["marina",            ["boat marina"]],
        ["may",               ["may possibly"]],
        ["meet",              ["meet together", "meet with each other"]],
        ["memories",          ["past memories"]],
        ["merge",             ["merge together"]],
        ["merged",            ["merged together"]],
        ["meshed",            ["meshed together"]],
        ["midnight",          ["twelve midnight"]],
        ["migraine",          ["migraine headache"]],
        ["minestrone",        ["minestrone soup"]],
        ["mix",               ["mix together"]],
        ["moment",            ["brief moment", "moment in time"]],
        ["monopoly",          ["complete monopoly"]],
        ["mural",             ["wall mural"]],
        ["mutual respect",    ["mutual respect for each other"]],
        ["mutually dependent", ["mutually dependent on each other"]],
        ["mystery",           ["unsolved mystery"]],
        # ["naked",             ["bare naked"]],
        ["nape",              ["nape of her neck"]],
        ["necessary",         ["absolutely necessary"]],
        ["never",             ["never at any time"]],
        ["noon",              ["12 noon", "12 o'clock noon", "high noon",
                               "twelve noon"]],
        ["nostalgia",         ["nostalgia for the past"]],
        ["number of",         ["number of different"]],
        ["opening",           ["exposed opening"]],
        ["my opinion",        ["my personal opinion"]],
        ["opposites",         ["exact opposites", "polar opposites"]],
        ["opposite",          ["exact opposite", "polar opposite"]],
        ["orbits",            ["orbits around"]],
        ["outcome",           ["final outcome"]],
        ["panacea",           ["universal panacea"]],
        ["pending",           ["now pending"]],
        ["penetrate",         ["penetrate through"]],
        ["persists",          ["still persists"]],
        ["pioneer",           ["old pioneer"]],
        ["plan",              ["plan ahead", "plan in advance",
                               "proposed plan"]],
        ["planning",          ["advance planning", "forward planning"]],
        ["plans",             ["future plans"]],
        ["plan",              ["future plan"]],
        ["point",             ["point in time"]],
        ["point",             ["sharp point"]],
        ["postpone",          ["postpone until later"]],
        ["pouring rain",      ["pouring down rain"]],
        ["preview",           ["advance preview"]],
        ["previously listed", ["previously listed above"]],
        ["probed",            ["probed into"]],
        ["proceed",           ["proceed ahead"]],
        ["prosthesis",        ["artificial prosthesis"]],
        # ["protrude",          ["protrude out"]],
        ["proverb",           ["old proverb"]],
        # ["proximity",         ["close proximity"]],
        ["put off",           ["put off until later"]],
        # ["raise",             ["raise up"]],
        ["re-elect",          ["re-elect for another term"]],
        ["reason is",         ["reason is because"]],
        ["recur",             ["recur again"]],
        ["recurrence",        ["future recurrence"]],
        ["refer",             ["refer back"]],
        ["reflect",           ["reflect back"]],
        # ["relevant",          ["highly relevant"]],
        ["remain",            ["continue to remain"]],
        ["remains",           ["still remains"]],
        ["replica",           ["exact replica"]],
        ["reply",             ["reply back"]],
        # ["requirements",      ["necessary requirements"]],
        ["reservations",      ["advance reservations"]],
        ["retreat",           ["retreat back"]],
        ["revert",            ["revert back"]],
        ["round",             ["round in shape"]],
        ["rule of thumb",     ["rough rule of thumb"]],
        ["rumor",             ["unconfirmed rumor"]],
        ["rustic",            ["rustic country"]],
        ["same",              ["exact same", "precise same", "same exact"]],
        ["sanctuary",         ["safe sanctuary"]],
        ["satisfaction",      ["full satisfaction"]],
        ["scrutinize",        ["scrutinize in detail"]],
        ["scrutiny",          ["careful scrutiny", "close scrutiny"]],
        ["secret",            ["secret that cannot be told"]],
        ["seek",              ["seek to find"]],
        ["separated",         ["separated apart from each other"]],
        ["share",             ["share together"]],
        ["shiny",             ["shiny in appearance"]],
        ["sincere",           ["truly sincere"]],
        ["sink",              ["sink down"]],
        ["skipped",           ["skipped over"]],
        # ["slow",              ["slow speed"]],
        # ["small",             ["small size"]],
        ["soft",              ["soft in texture", "soft to the touch"]],
        ["sole",              ["sole of the foot"]],
        ["some time",         ["some time to come"]],
        ["speck",             ["small speck"]],
        ["speed",             ["rate of speed"]],
        ["spell out",         ["spell out in detail"]],
        ["spiked",            ["spiked upward", "spiked upwards"]],
        ["spring",            ["spring season"]],
        ["stranger",          ["anonymous stranger"]],
        ["studio audience",   ["live studio audience"]],
        ["subway",            ["underground subway"]],
        ["sufficient",        ["sufficient enough"]],
        ["summer",            ["summer season"]],
        ["sure",              ["absolutely sure"]],
        ["surprise",          ["unexpected surprise"]],
        ["surround",          ["completely surround"]],
        ["surrounded",        ["surrounded on all sides"]],
        ["tall",              ["tall in height", "tall in stature"]],
        ["telepathy",         ["mental telepathy"]],
        ["ten",               ["ten in number"]],
        ["these",             ["these ones"]],
        # ["they",              ["they themselves"]],
        ["those",             ["those ones"]],
        ["trench",            ["open trench"]],
        ["truth",             ["honest truth"]],
        ["tundra",            ["frozen tundra"]],
        ["ultimatum",         ["final ultimatum"]],
        # ["undeniable",        ["undeniable truth"]],
        ["undergraduate",     ["undergraduate student"]],
        # ["unintentional",     ["unintentional mistake"]],
        ["vacillate",         ["vacillate back and forth"]],
        ["veteran",           ["former veteran"]],
        ["visible",           ["visible to the eye"]],
        ["warn",              ["warn in advance"]],
        ["warning",           ["advance warning"]],
        ["water heater",      ["hot water heater"]],
        ["in which we live",  ["in which we live in"]],
        ["winter",            ["winter season"]],
        ["witness",           ["live witness"]],
        ["yakitori",          ["yakitori chicken"]],
        ["yerba mate",        ["yerba mate tea"]],
        ["yes",               ["affirmative yes"]],
    ]

    return preferred_forms_check(text, redundancies, err, msg)



# -*- coding: utf-8 -*-

"""Command line utility for proselint."""
from __future__ import print_function
from __future__ import absolute_import
from builtins import str


import click
import os
from .tools import (
    close_cache_shelves_after,
    close_cache_shelves,
    errors_to_json,
    lint,
)
import shutil
import subprocess
import sys
from .version import __version__
import traceback


CONTEXT_SETTINGS = dict(help_option_names=['-h', '--help'])
base_url = "proselint.com/"
proselint_path = os.path.dirname(os.path.realpath(__file__))
demo_file = os.path.join(proselint_path, "demo.md")


# TODO: fix broken corpus
def timing_test(corpus="0.1.0"):
    """Measure timing performance on the named corpus."""
    import time
    dirname = os.path.dirname
    corpus_path = os.path.join(
        dirname(dirname(os.path.realpath(__file__))), "corpora", corpus)
    start = time.time()
    for file in os.listdir(corpus_path):
        filepath = os.path.join(corpus_path, file)
        if ".md" == filepath[-3:]:
            subprocess.call(["proselint", filepath, ">/dev/null"])

    return time.time() - start


def clear_cache():
    """Delete the contents of the cache."""
    click.echo("Deleting the cache...")

    # see issue #624
    _delete_compiled_python_files()
    _delete_cache()


def _delete_compiled_python_files():
    """Remove files with a 'pyc' extension."""
    for path, _, files in os.walk(os.getcwd()):
        for fname in [f for f in files if os.path.splitext(f)[1] == ".pyc"]:
            try:
                os.remove(os.path.join(path, fname))
            except OSError:
                pass


def _delete_cache():
    """Remove the proselint cache."""
    proselint_cache = os.path.join("proselint", "cache")
    try:
        shutil.rmtree(proselint_cache)
    except OSError:
        pass


def print_errors(filename, errors, output_json=False, compact=False):
    """Print the errors, resulting from lint, for filename."""
    if output_json:
        click.echo(errors_to_json(errors))

    else:
        for error in errors:

            (check, message, line, column, start, end,
             extent, severity, replacements) = error

            if compact:
                filename = "-"

            click.echo(
                filename + ":" +
                str(1 + line) + ":" +
                str(1 + column) + ": " +
                check + " " +
                message)


@click.command(context_settings=CONTEXT_SETTINGS)
@click.version_option(__version__, '--version', '-v', message='%(version)s')
@click.option('--config', is_flag=False, type=click.Path(),
              help="Path to configuration file.")
@click.option('--debug', '-d', is_flag=True, help="Give verbose output.")
@click.option('--clean', '-c', is_flag=True, help="Clear the cache.")
@click.option('--json', '-j', 'output_json', is_flag=True,
              help="Output as JSON.")
@click.option('--time', '-t', is_flag=True, help="Time on a corpus.")
@click.option('--demo', is_flag=True, help="Run over demo file.")
@click.option('--compact', is_flag=True, help="Shorten output.")
@click.argument('paths', nargs=-1, type=click.Path())
@close_cache_shelves_after
def proselint(paths=None, config=None, version=None, clean=None, debug=None,
              output_json=None, time=None, demo=None, compact=None):
    """Create the CLI for proselint, a linter for prose."""
    if time:
        # click.echo(timing_test())
        print("This option does not work for the time being.")
        return

    # In debug or clean mode, delete cache & *.pyc files before running.
    if debug or clean:
        clear_cache()

    # Use the demo file by default.
    if demo:
        paths = [demo_file]

    # Expand the list of directories and files.
    filepaths = extract_files(list(paths))

    # Lint the files
    num_errors = 0

    # Use stdin if no paths were specified
    if len(paths) == 0:
        filepaths.append('-')

    for fp in filepaths:
        if fp == '-':
            fp = '<stdin>'
            f = sys.stdin
        else:
            try:
                f = click.open_file(
                    fp, 'r', encoding="utf-8", errors="replace")
            except Exception:
                traceback.print_exc()
                sys.exit(2)
        errors = lint(f, debug=debug, config_file_path=config)
        num_errors += len(errors)
        print_errors(fp, errors, output_json, compact=compact)

    # Return an exit code
    close_cache_shelves()
    if num_errors > 0:
        sys.exit(1)
    else:
        sys.exit(0)


def extract_files(files):
    """Expand list of paths to include all text files matching the pattern."""
    expanded_files = []
    legal_extensions = [".md", ".txt", ".rtf", ".html", ".tex", ".markdown"]

    for f in files:
        # If it's a directory, recursively walk through it and find the files.
        if os.path.isdir(f):
            for dir_, _, filenames in os.walk(f):
                for filename in filenames:
                    fn, file_extension = os.path.splitext(filename)
                    if file_extension in legal_extensions:
                        joined_file = os.path.join(dir_, filename)
                        expanded_files.append(joined_file)

        # Otherwise add the file directly.
        else:
            expanded_files.append(f)

    return expanded_files


if __name__ == '__main__':
    proselint()



# -*- coding: utf-8 -*-
u"""False plurals.

---
layout:     post
source:     Garner's Modern American Usage
source_url: http://bit.ly/1T4alrY
title:      False plurals.
date:       2014-06-10 12:31:19
categories: writing
---

Using the incorrect form of the plural.

"""
from proselint.tools import memoize, preferred_forms_check, existence_check


@memoize
def check(text):
    """Suggest the preferred forms."""
    err = "misc.false_plurals.examples"
    msg = "The plural is {}"

    preferences = [
        ["talismans", ["talismen"]],
        ["phenomena", ["phenomenons"]],
    ]

    return preferred_forms_check(text, preferences, err, msg)


@memoize
def check_kudos(text):
    """Check the text."""
    err = "misc.false_plurals.kudos"
    msg = u"Kudos is singular."

    return existence_check(text, ["many kudos"], err, msg)



# -*- coding: utf-8 -*-
"""Metadiscourse.

---
layout:     post
source:     Pinker's book on writing
source_url: ???
title:      metadiscourse
date:       2014-06-10 12:31:19
categories: writing
---

Points out metadiscourse.

"""
from proselint.tools import memoize, existence_check


@memoize
def check(text):
    """Suggest the preferred forms."""
    err = "pinker.metadiscourse"
    msg = "Excessive metadiscourse."

    metadiscourse = [
        "The preceeding discussion",
        "The rest of this article",
        "This chapter discusses",
        "The preceding paragraph demonstrated",
        "The previous section analyzed",
    ]

    return existence_check(text, metadiscourse, err, msg)



"""Lexical illusions.

---
layout:     post
source:     write-good
source_url: https://github.com/btford/write-good
title:      Lexical illusion present
date:       2014-06-10 12:31:19
categories: writing
---

A lexical illusion is when a word word is unintentionally repeated twice, and
and this happens most often between line breaks.

"""
from proselint.tools import existence_check, memoize


@memoize
def check(text):
    """Check the text."""
    err = "lexical_illusions.misc"
    msg = u"There's a lexical illusion here: a word is repeated."
    regex = r"\b(\w+)(\b\s\1)+"
    exceptions = [r"^had had$", r"^that that$"]

    return existence_check(text, [regex], err, msg, exceptions=exceptions,
                           require_padding=False)



# -*- coding: utf-8 -*-

"""Redundant Acronym Syndrome (RAS) syndrome."""

from proselint.tools import memoize, preferred_forms_check


@memoize
def check(text):
    """Suggest the preferred forms."""
    err = "garner.redundancy.ras"
    msg = "RAS syndrome. Use '{}' instead of '{}'."

    redundancies = [
        ["ABM",               ["ABM missile"]],
        ["ACT",               ["ACT test"]],
        ["ABMs",              ["ABM missiles"]],
        ["ABS",               ["ABS braking system"]],
        ["ATM",               ["ATM machine"]],
        ["CD",                ["CD disc"]],
        ["CPI",               ["CPI Index"]],
        ["GPS",               ["GPS system"]],
        ["GUI",               ["GUI interface"]],
        ["HIV",               ["HIV virus"]],
        ["ISBN",              ["ISBN number"]],
        ["LCD",               ["LCD display"]],
        ["PDF",               ["PDF format"]],
        ["PIN",               ["PIN number"]],
        ["RAS",               ["RAS syndrome"]],
        ["RIP",               ["RIP in peace"]],
        ["RSVP",              ["please RSVP"]],
        ["SALT",              ["SALT talks"]],
        ["SAT",               ["SAT test"]],
        ["UPC",               ["UPC codes"]],
    ]

    return preferred_forms_check(text, redundancies, err, msg)



# -*- coding: utf-8 -*-
"""Inconsistent spelling.

---
layout:     post
source:     Intelligent Editing Ltd.
source_url: http://bit.ly/1x3hYj7
title:      Inconsistent spelling
date:       2014-06-10 12:31:19
categories: writing
---

Intelligent Editing Ltd. says:

> Some words have more than one correct spelling. American, British, Australian
and Canadian English all have their own preferences. Even within those, there
can be multiple spellings. For example, in the UK 'realise' is often preferred.
However, 'realize' has been used in British-English for centuries and is
preferred in the Oxford English Dictionary. However, no matter which spelling
is preferred, one thing is always wrong: you mustn't use two different
spellings in the same document.
"""
from proselint.tools import consistency_check, memoize


@memoize
def check(text):
    """Check the text."""
    err = "consistency.spelling"
    msg = "Inconsistent spelling of '{}' (vs. '{}')."

    word_pairs = [
        ["advisor", "adviser"],
        # ["analyse", "analyze"],
        ["centre", "center"],
        ["colour", "color"],
        ["emphasise", "emphasize"],
        ["finalise", "finalize"],
        ["focussed", "focused"],
        ["labour", "labor"],
        ["learnt", "learned"],
        ["organise", "organize"],
        ["organised", "organized"],
        ["organising", "organizing"],
        ["recognise", "recognize"],
    ]

    return consistency_check(text, word_pairs, err, msg)



# -*- coding: utf-8 -*-
"""Names for groups of animals.

---
layout:     post
source:     Oxford Dictionaries
source_url: http://www.oxforddictionaries.com/words/what-do-you-call-a-group-of
title:      Names for groups of animals
date:       2014-06-10 12:31:19
categories: writing
---

Names for groups of animals.

"""
from proselint.tools import preferred_forms_check, memoize


@memoize
def check(text):
    """Check the text."""
    err = "oxford.venery_terms"
    msg = "The venery term is '{}'."

    term_list = [
        ["alligators",   "congregation"],
        ["antelopes",    "herd"],
        ["baboons",      "troop"],
        ["badgers",      "cete"],
        ["bats",         "colony"],
        ["bears",        "sloth"],
        ["buffalo",      "herd"],
        ["bullfinches",  "bellowing"],
        ["caribou",      "herd"],
        ["cats",         "glaring"],
        ["caterpillars", "army"],
        ["cockroaches",  "intrusion"],
        ["coyotes",      "pack"],
        ["crows",        "murder"],
        ["dogs",         "pack"],
        ["eagles",       "convocation"],
        ["emus",         "mob"],
        ["flamingos",    "stand"],
        ["frogs",        "army"],
        ["goldfinches",  "charm"],
        ["gorillas",     "band"],
        ["guineafowl",   "rasp"],
        ["hedgehogs",    "array"],
        ["herons",       "siege"],
        ["hogs",         "parcel"],
        ["hyenas",       "cackle"],
        ["ibex",         "herd"],
        ["iguanas",      "mess"],
        ["lions",        "pride"],
        ["locusts",      "plague"],
        ["mackerel",     "shoal"],
        ["mares",        "stud"],
        ["minnows",      "shoal"],
        ["moose",        "herd"],
        ["mosquitoes",   "scourge"],
        ["nightingales", "watch"],
        ["oysters",      "bed"],
        ["partridges",   "covey"],
        ["pelicans",     "pod"],
        ["raccoons",     "gaze"],
        ["ravens",       "unkindness"],
        ["rhinoceroses", "crash"],
        ["sea urchins",  "sea"],
        ["starlings",    "murmuration"],
        ["toads",        "knot"],
        ["wombats",      "wisdom"],
        ["woodcocks",    "fall"],
        ["woodpeckers",  "descent"],
        ["wrens",        "herd"],
    ]

    generic_terms = [
        "group",
        "bunch",
    ]

    list = []
    for term_pair in term_list:
        for generic in generic_terms:
            wrong = "a {} of {}".format(generic, term_pair[0])
            right = "a {} of {}".format(term_pair[1], term_pair[0])
            list += [[right, [wrong]]]

    return preferred_forms_check(text, list, err, msg)



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['proselint',
 'proselint.checks',
 'proselint.checks.airlinese',
 'proselint.checks.annotations',
 'proselint.checks.archaism',
 'proselint.checks.cliches',
 'proselint.checks.consistency',
 'proselint.checks.corporate_speak',
 'proselint.checks.cursing',
 'proselint.checks.dates_times',
 'proselint.checks.hedging',
 'proselint.checks.hyperbole',
 'proselint.checks.inprogress',
 'proselint.checks.jargon',
 'proselint.checks.lexical_illusions',
 'proselint.checks.lgbtq',
 'proselint.checks.links',
 'proselint.checks.malapropisms',
 'proselint.checks.misc',
 'proselint.checks.mixed_metaphors',
 'proselint.checks.mondegreens',
 'proselint.checks.needless_variants',
 'proselint.checks.nonwords',
 'proselint.checks.oxymorons',
 'proselint.checks.psychology',
 'proselint.checks.redundancy',
 'proselint.checks.security',
 'proselint.checks.sexism',
 'proselint.checks.skunked_terms',
 'proselint.checks.spelling',
 'proselint.checks.terms',
 'proselint.checks.typography',
 'proselint.checks.uncomparables',
 'proselint.checks.weasel_words']

package_data = \
{'': ['*']}

install_requires = \
['click>=8.0.0,<9.0.0', 'future>=0.18.2,<0.19.0', 'six>=1.15.0,<2.0.0']

setup_kwargs = {
    'name': 'proselint',
    'version': '0.11.0',
    'description': 'A linter for prose.',
    'long_description': None,
    'author': 'Amperser Labs',
    'author_email': 'hello@amperser.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



"""Use of greylisted words.

---
layout:     post
source:     Strunk & White
source_url: ???
title:      Use of greylisted words
date:       2014-06-10 12:31:19
categories: writing
---

Strunk & White say:


"""
from proselint.tools import memoize
import re


@memoize
def check(text):
    """Check the text."""
    err = "strunk_white.greylist"
    msg = "Use of '{}'. {}"

    bad_words = [
        "obviously",
        "utilize"
    ]

    explanations = {
        "obviously":
        "This is obviously an inadvisable word to use.",
        "utilize":
        r"Do you know anyone who *needs* to utilize the word utilize?"
    }

    errors = []
    for word in bad_words:
        occ = [m for m in re.finditer(word, text.lower())]
        for o in occ:
            errors.append((
                o.start(),
                o.end(),
                err,
                msg.format(word, explanations[word]),
                None))

    return errors



# -*- coding: utf-8 -*-
"""Back-formations.

---
layout:     post
source:     The sense of style
source_url: http://amzn.to/1EOUZ5g
title:      back-formations
date:       2014-06-10 12:31:19
categories: writing
---

Back-formations.

"""
from proselint.tools import memoize, preferred_forms_check


@memoize
def check(text):
    """Suggest the preferred forms."""
    err = "pinker.latin"
    msg = "Use English. '{}' is the preferred form."

    list = [
        ["other things being equal",          ["ceteris paribus"]],
        ["among other things",                ["inter alia"]],
        ["in and of itself",                  ["simpliciter"]],
        ["having made the necessary changes", ["mutatis mutandis"]],
    ]

    return preferred_forms_check(text, list, err, msg)



# -*- coding: utf-8 -*-
"""Misuse of scare quotes.

---
layout:     post
source:     Pinker's book on writing
source_url: ???
title:      misuse of scare quotes
date:       2014-06-10 12:31:19
categories: writing
---

Points out misuse of scare quotes.

"""
from proselint.tools import memoize, existence_check


@memoize
def check(text):
    """Suggest the preferred forms."""
    err = "pinker.scare_quotes"
    msg = "Misuse of 'scare quotes'. Delete them."

    narcissism = [
        "the 'take-home message'",
    ]

    return existence_check(text, narcissism, err, msg)



# -*- coding: utf-8 -*-
"""Tense present.

---
layout:     post
source:     DFW's Tense Present
source_url: http://bit.ly/1c85lgR
title:      Tense present
date:       2014-06-10 12:31:19
categories: writing
---

Archaism.

"""
from proselint.tools import memoize
import re


@memoize
def check(text):
    """Check the text."""
    err = "misc.tense_present"
    msg = r"'{}'."

    illogics = [
        r"up to \d{1,3}% ?[-\u2014\u2013]{0,3} ?(?:or|and) more\W?",
        "between you and I",
        "on accident",
        "somewhat of a",
        "all it's own",
        "reason is because",
        "audible to the ear",
        "in regards to",
        "would of",
        # "and so",
        r"i ?(?:feel|am feeling|am|'m|'m feeling) nauseous",
    ]

    errors = []
    for i in illogics:
        for m in re.finditer(r"\s{}\s".format(i), text, flags=re.U | re.I):
            txt = m.group(0).strip()
            errors.append((
                m.start() + 1,
                m.end(),
                err,
                msg.format(txt),
                None))

    return errors



# -*- coding: utf-8 -*-
"""Eponymous adjectives.

---
layout:     post
source:     Garner's Modern American Usage
source_url: http://bit.ly/1T4alrY
title:      Eponymous adjectives
date:       2014-06-10 12:31:19
categories: writing
---

Eponymous adjectives.

"""
from proselint.tools import memoize, preferred_forms_check


@memoize
def check(text):
    """Suggest the preferred forms."""
    err = "garner.eponymous_adjective"
    msg = "'{}' is the preferred eponymous adjective."

    preferences = [

        ["Mephistophelean",    ["Mephistophelian"]],
        ["Shakespearean",      ["Shakespearian"]],
    ]

    return preferred_forms_check(text, preferences, err, msg)



# -*- coding: utf-8 -*-
"""Malaproprisms.

---
layout:     post
source:     Garner's Modern American Usage
source_url: http://bit.ly/1T4alrY
title:      Malaproprisms
date:       2014-06-10 12:31:19
categories: writing
---

Archaism.

"""
from proselint.tools import existence_check, memoize


@memoize
def check(text):
    """Check the text."""
    err = "malapropisms.misc"
    msg = u"'{}' is a malapropism."

    illogics = [
        "the infinitesimal universe",
        "a serial experience",
        "attack my voracity",
    ]

    return existence_check(text, illogics, err, msg, offset=1)



# -*- coding: utf-8 -*-
"""Back-formations.

---
layout:     post
source:     Garner's Modern American Usage
source_url: http://bit.ly/1T4alrY
title:      back-formations
date:       2014-06-10 12:31:19
categories: writing
---

Back-formations.

"""
from proselint.tools import memoize, preferred_forms_check


@memoize
def check(text):
    """Suggest the preferred forms."""
    err = "misc.back_formations"
    msg = "Back-formation. '{}' is the preferred form."

    list = [
        ["improper",       ["improprietous"]],
    ]

    return preferred_forms_check(text, list, err, msg)
